@@ -3,7 +3,7 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified January 26, 2021
+Last modified July 28, 2022
 
 Description:  Compares reads to the kmers in a reference dataset, optionally 
 allowing an edit distance. Splits the reads into two outputs - those that 
@@ -172,11 +172,14 @@ Note - if ktrim, kmask, and ksplit are unset, the default behavior is kfilter.
 All kmer processing modes are mutually exclusive.
 Reads only get sent to 'outm' purely based on kmer matches in kfilter mode.
 
-ktrim=f             Trim reads to remove bases matching reference kmers.
+ktrim=f             Trim reads to remove bases matching reference kmers, plus
+                    all bases to the left or right.
                     Values: 
                        f (don't trim), 
                        r (trim to the right), 
                        l (trim to the left)
+ktrimtips=0         Set this to a positive number to perform ktrim on both
+                    ends, examining only the outermost X bases.
 kmask=              Replace bases matching ref kmers with another symbol.
                     Allows any non-whitespace character, and processes short
                     kmers on both ends if mink is set.  'kmask=lc' will
@@ -237,6 +240,8 @@ restrictleft=0      If positive, only look for kmer matches in the
                     leftmost X bases.
 restrictright=0     If positive, only look for kmer matches in the 
                     rightmost X bases.
+NOTE:  restrictleft and restrictright are mutually exclusive.  If trimming
+       both ends is desired, use ktrimtips.
 mingc=0             Discard reads with GC content below this.
 maxgc=1             Discard reads with GC content above this.
 gcpairs=t           Use average GC of paired reads.
