@@ -441,8 +441,7 @@ public class BBSplitter {
 			}
 			tf.close();
 		}
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 		
 		return refname;
 	}
@@ -1154,8 +1153,7 @@ public class BBSplitter {
 			
 			tsw.println("samtools index "+bam3);
 		}
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 		
 		try {
 			File f=new File(outname);
@@ -1237,7 +1235,7 @@ public class BBSplitter {
 				sb.setLength(0);
 			}
 		}
-		tsw.poison();
+		tsw.poisonAndWait();
 	}
 	
 	static final void clearStatics(){
