@@ -4,7 +4,7 @@ import java.io.File;
 import java.util.Locale;
 
 import fileIO.ReadWrite;
-import shared.Tools;
+import shared.Parse;
 
 public class PrintTime {
 	
@@ -24,7 +24,7 @@ public class PrintTime {
 //				tf.close();
 				long old=Long.parseLong(s);
 				long elapsed=millis-old;
-				if(args.length<2 || Tools.parseBoolean(args[1])){
+				if(args.length<2 || Parse.parseBoolean(args[1])){
 					System.out.println("Elapsed:\t"+String.format(Locale.ROOT, "%.2f", elapsed/1000d));
 					if(true){
 						System.err.println("Elapsed:\t"+String.format(Locale.ROOT, "%.2f", elapsed/1000d));
