@@ -3,6 +3,7 @@ package assemble;
 import java.util.ArrayList;
 import java.util.concurrent.atomic.AtomicInteger;
 
+import shared.KillSwitch;
 import structures.ByteBuilder;
 
 /**
@@ -35,9 +36,9 @@ public abstract class AbstractProcessContigThread extends Thread {
 
 	abstract void processContigRight(Contig c, int[] leftCounts, int[] rightCounts, int[] extraCounts, ByteBuilder bb);
 
-	final int[] leftCounts=new int[4];
-	final int[] rightCounts=new int[4];
-	final int[] extraCounts=new int[4];
+	final int[] leftCounts=KillSwitch.allocInt1D(4);
+	final int[] rightCounts=KillSwitch.allocInt1D(4);
+	final int[] extraCounts=KillSwitch.allocInt1D(4);
 
 	final ArrayList<Contig> contigs;
 	final AtomicInteger next;
