@@ -11,9 +11,9 @@ import dna.Data;
 import fileIO.ReadWrite;
 import jgi.BBDuk;
 import jgi.BBMerge;
+import shared.Parse;
 import shared.PreParser;
 import shared.Shared;
-import shared.Tools;
 import stream.FASTQ;
 
 /**
@@ -76,9 +76,9 @@ public class TadPipe {
 				assert(false) : "Unsupported";
 //				phix=b;
 			}else if(a.equals("delete")){
-				deleteTemp=Tools.parseBoolean(b);
+				deleteTemp=Parse.parseBoolean(b);
 			}else if(a.equals("gz")){
-				gz=Tools.parseBoolean(b);
+				gz=Parse.parseBoolean(b);
 			}else if(a.equals("tmpdir") || a.equals("tempdir") || a.equals("temp")){
 				tempdir=(b+"/").replaceAll("\\\\", "/").replaceAll("//", "/");
 			}else if(a.startsWith("merge_")){
