@@ -178,7 +178,6 @@ public class BloomFilter implements Serializable {
 		if(extra_!=null){
 			for(String s : extra_){extra.add(s);}
 		}
-
 		filterMemory=setMemory(memFraction);
 		
 		in1=in1_;
@@ -247,9 +246,10 @@ public class BloomFilter implements Serializable {
 		final long totalBits=8*filterMemory;
 		final long cells=(OVERRIDE_CELLS>0 ? OVERRIDE_CELLS : totalBits/cbits);
 //		System.err.println("filterMemory="+filterMemory+", cells="+cells);
-		KCountArray7MTA kca=(KCountArray7MTA)KmerCount7MTA.makeKca(in1, in2, extra==null || extra.isEmpty() ? null : extra,
-				k, cbits, 0, cells, hashes, minq, rcomp, ecco, merge,
-				maxReads, 1, 1, 1, 1, null, 0, Shared.AMINO_IN);
+		ReadCounter rc=new ReadCounter(k, rcomp, ecco, merge, Shared.AMINO_IN);
+		KCountArray7MTA kca=(KCountArray7MTA)rc.makeKca(in1, in2, extra==null || extra.isEmpty() ? null : extra,
+				cbits, cells, hashes, minq,
+				maxReads, 1, 1, 1, 1, null, 0);
 		return kca;
 	}
 
@@ -259,7 +259,8 @@ public class BloomFilter implements Serializable {
 		final long totalBits=8*filterMemory;
 		final long cells=totalBits/cbits;
 		outstream.println("Filter Memory = "+String.format(Locale.ROOT, "%.2f GB", filterMemory/(double)(1024*1024*1024)));
-		KCountArray7MTA kca=(KCountArray7MTA)KmerCount7MTA.makeKcaFromIndex(k, cbits, cells, hashes, rcomp);
+		IndexCounter ic=new IndexCounter(k, rcomp);
+		KCountArray7MTA kca=(KCountArray7MTA)ic.makeKcaFromIndex(cells, cbits, hashes);
 		return kca;
 	}
 	
