@@ -135,7 +135,7 @@ public class BloomFilterCorrectorWrapper {
 			}else if(a.equals("mincount")){
 				minCount_=Integer.parseInt(b);
 			}else if(a.equals("minprob")){
-				KmerCount7MTA.minProb=Float.parseFloat(b);
+				ReadCounter.minProb=Float.parseFloat(b);
 			}else if(a.equals("maxload")){
 				maxLoad=Float.parseFloat(b);
 			}else if(a.equals("requireboth")){
@@ -259,7 +259,7 @@ public class BloomFilterCorrectorWrapper {
 			extout=parser.extout;
 			
 //			parser.loglogk=k;
-			parser.loglogMinprob=KmerCount7MTA.minProb;
+			parser.loglogMinprob=ReadCounter.minProb;
 			loglogOut=((parser.loglog&parser.loglogOut) ? CardinalityTracker.makeTracker(parser) : null);
 		}
 		
