@@ -5,6 +5,7 @@ import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Locale;
 
+import dna.AminoAcid;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
@@ -118,10 +119,10 @@ public class BloomFilterWrapper {
 				assert(bits_>0);
 			}else if(a.equals("mincount")){
 				minCount_=Integer.parseInt(b);
-				assert(minCount_>=1) : "mincount must be at least 1.";
-				minCount_=Tools.max(1, minCount_);
+//				assert(minCount_>=1) : "mincount must be at least 1.";
+//				minCount_=Tools.max(1, minCount_);
 			}else if(a.equals("minprob")){
-				KmerCount7MTA.minProb=Float.parseFloat(b);
+				ReadCounter.minProb=Float.parseFloat(b);
 			}else if(a.equals("requireboth")){
 				requireBothToMatch_=Parse.parseBoolean(b);
 			}else if(a.equals("ecco")){
@@ -143,7 +144,8 @@ public class BloomFilterWrapper {
 			}
 			
 			else if(a.equals("ref")){
-				Tools.addFiles(b, ref);
+				boolean result=Tools.addFiles(b, ref);
+				assert(result) : "Could not add file(s): "+b;
 			}else if(a.equals("outm") || a.equals("outm1") || a.equals("outbad") || a.equals("outbad1") || a.equals("outmatch") || a.equals("outmatch1")){
 				outm1=b;
 			}else if(a.equals("outm2") || a.equals("outbad2") || a.equals("outmatch2")){
@@ -152,6 +154,8 @@ public class BloomFilterWrapper {
 				out1=b;
 			}else if(a.equals("outu2") || a.equals("out2")){
 				out2=b;
+			}else if(a.equals("outc") || a.equals("counts")){
+				outc=b;
 			}else if(a.equals("parse_flag_goes_here")){
 				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
@@ -176,6 +180,10 @@ public class BloomFilterWrapper {
 		merge=merge_;
 		KmerCountAbstract.CANONICAL=rcomp; //rcomp, or true, perhaps...  hmmm.
 		
+		shift=bitsPerBase*k;
+		shift2=shift-bitsPerBase;
+		mask=(shift>63 ? -1L : ~((-1L)<<shift));
+		
 		{//Process parser fields
 			Parser.processQuality();
 			
@@ -272,11 +280,13 @@ public class BloomFilterWrapper {
 		//Create output FileFormat objects
 		ffoutm1=FileFormat.testOutput(outm1, FileFormat.FASTQ, extout, true, overwrite, append, ordered);
 		ffoutm2=FileFormat.testOutput(outm2, FileFormat.FASTQ, extout, true, overwrite, append, ordered);
+		
+		ffoutc=FileFormat.testOutput(outc, FileFormat.FASTA, extout, true, overwrite, append, ordered);
 
 		//Create input FileFormat objects
-		ffin1=FileFormat.testInput(in1, FileFormat.FASTQ, extin, true, true);
-		ffin2=FileFormat.testInput(in2, FileFormat.FASTQ, extin, true, true);
-
+		ffin1=FileFormat.testInput(in1, FileFormat.FASTA, extin, true, true);
+		ffin2=FileFormat.testInput(in2, FileFormat.FASTA, extin, true, true);
+		
 		{
 			Timer t=new Timer(outstream, true);
 			if(serialIn==null){
@@ -290,6 +300,10 @@ public class BloomFilterWrapper {
 			}
 			t.stop("Filter creation: \t\t");
 			outstream.println(filter.filter.toShortString());
+			if(verbose){
+				outstream.println("Keys Counted: "+KmerCountAbstract.keysCounted);
+				outstream.println("Increments:   "+KmerCountAbstract.increments);
+			}
 		}
 	}
 	
@@ -315,7 +329,7 @@ public class BloomFilterWrapper {
 		if(!ffin1.samOrBam()){outstream.println("Input is being processed as "+(paired ? "paired" : "unpaired"));}
 		
 		//Optionally create read output streams
-		final ConcurrentReadOutputStream rosu, rosm;
+		final ConcurrentReadOutputStream rosu, rosm, rosc;
 		if(ffout1!=null){
 			//Select output buffer size based on whether it needs to be ordered
 			final int buff=(ordered ? Tools.mid(16, 128, (Shared.threads()*2)/3) : 8);
@@ -337,6 +351,14 @@ public class BloomFilterWrapper {
 			rosm.start(); //Start the stream
 		}else{rosm=null;}
 		
+		if(ffoutc!=null){
+			//Select output buffer size based on whether it needs to be ordered
+			final int buff=(ordered ? Tools.mid(16, 128, (Shared.threads()*2)/3) : 8);
+			
+			rosc=ConcurrentReadOutputStream.getStream(ffoutc, null, buff, null, false);
+			rosc.start(); //Start the stream
+		}else{rosc=null;}
+		
 		//Reset counters
 		readsProcessed=readsOut=0;
 		basesProcessed=basesOut=0;
@@ -344,14 +366,14 @@ public class BloomFilterWrapper {
 		Timer t2=new Timer(outstream, true);
 		
 		//Process the reads in separate threads
-		spawnThreads(cris, rosu, rosm);
+		spawnThreads(cris, rosu, rosm, rosc);
 		
 		if(verbose){outstream.println("Finished; closing streams.");}
 		
 		//Write anything that was accumulated by ReadStats
 		errorState|=ReadStats.writeAll();
 		//Close the read streams
-		errorState|=ReadWrite.closeStreams(cris, rosu, rosm);
+		errorState|=ReadWrite.closeStreams(cris, rosu, rosm, rosc);
 		
 		//Reset read validation
 		Read.VALIDATE_IN_CONSTRUCTOR=vic;
@@ -380,7 +402,9 @@ public class BloomFilterWrapper {
 	}
 	
 	/** Spawn process threads */
-	private void spawnThreads(final ConcurrentReadInputStream cris, final ConcurrentReadOutputStream rosu, final ConcurrentReadOutputStream rosm){
+	private void spawnThreads(final ConcurrentReadInputStream cris, 
+			final ConcurrentReadOutputStream rosu, final ConcurrentReadOutputStream rosm,
+			final ConcurrentReadOutputStream rosc){
 		
 		//Do anything necessary prior to processing
 		
@@ -390,7 +414,7 @@ public class BloomFilterWrapper {
 		//Fill a list with ProcessThreads
 		ArrayList<ProcessThread> alpt=new ArrayList<ProcessThread>(threads);
 		for(int i=0; i<threads; i++){
-			alpt.add(new ProcessThread(cris, rosu, rosm, i));
+			alpt.add(new ProcessThread(cris, rosu, rosm, rosc, i));
 		}
 		
 		//Start the threads
@@ -439,10 +463,13 @@ public class BloomFilterWrapper {
 	private class ProcessThread extends Thread {
 		
 		//Constructor
-		ProcessThread(final ConcurrentReadInputStream cris_, final ConcurrentReadOutputStream rosu_, final ConcurrentReadOutputStream rosm_, final int tid_){
+		ProcessThread(final ConcurrentReadInputStream cris_, 
+				final ConcurrentReadOutputStream rosu_, final ConcurrentReadOutputStream rosm_, 
+				final ConcurrentReadOutputStream rosc_, final int tid_){
 			cris=cris_;
 			rosu=rosu_;
 			rosm=rosm_;
+			rosc=rosc_;
 			tid=tid_;
 		}
 		
@@ -477,6 +504,7 @@ public class BloomFilterWrapper {
 			while(ln!=null && reads!=null && reads.size()>0){//ln!=null prevents a compiler potential null access warning
 //				if(verbose){outstream.println("Fetched "+reads.size()+" reads.");} //Disabled due to non-static access
 				ArrayList<Read> matched=new ArrayList<Read>(reads.size());
+				ArrayList<Read> counts=(rosc==null ? null : new ArrayList<Read>(reads.size()));
 
 				//Loop through each read in the list
 				for(int idx=0; idx<reads.size(); idx++){
@@ -512,6 +540,10 @@ public class BloomFilterWrapper {
 							}
 						}
 
+						if(rosc!=null){
+							addCounts(r1, counts);
+							addCounts(r2, counts);
+						}
 						final boolean match=matchesFilter(r1, r2);
 						if(match){
 							reads.set(idx, null);
@@ -526,6 +558,7 @@ public class BloomFilterWrapper {
 				//Output reads to the output streams
 				if(rosu!=null){rosu.add(reads, ln.id);}
 				if(rosm!=null){rosm.add(matched, ln.id);}
+				if(rosc!=null){rosc.add(counts, ln.id);}
 
 				//Notify the input stream that the list was used
 				cris.returnList(ln);
@@ -541,6 +574,43 @@ public class BloomFilterWrapper {
 				cris.returnList(ln.id, ln.list==null || ln.list.isEmpty());
 			}
 		}
+
+		/**
+		 * Breaks a read into kmers and adds them, with their counts, to the new list.
+		 * @param r Read to process
+		 * @param counts Output list of kmers (bases) and counts (read name)
+		 */
+		private void addCounts(Read r, ArrayList<Read> counts){
+			if(r==null){return;}
+			final byte[] bases=r.bases;
+
+			long kmer=0;
+			long rkmer=0;
+			int len=0;
+
+			for(int i=0; i<bases.length; i++){
+				byte b=bases[i];
+				long x=AminoAcid.baseToNumber[b];
+				long x2=AminoAcid.baseToComplementNumber[b];
+				kmer=((kmer<<bitsPerBase)|x)&mask;
+				rkmer=((rkmer>>>bitsPerBase)|(x2<<shift2))&mask;
+				if(x<0){
+					len=0;
+					kmer=rkmer=0;
+				}else{
+					len++;
+					if(len>=k){
+						long key=rcomp ? Tools.max(kmer, rkmer) : kmer;
+						int count=filter.getCount(key);
+						if(count>=minCount){
+							String s=AminoAcid.kmerToString(key, k);
+							Read cread=new Read(s.getBytes(), null, ""+count, r.numericID);
+							counts.add(cread);
+						}
+					}
+				}
+			}
+		}
 		
 		/**
 		 * Process a read or a read pair.
@@ -579,6 +649,8 @@ public class BloomFilterWrapper {
 		private final ConcurrentReadOutputStream rosu;
 		/** Matched output stream */
 		private final ConcurrentReadOutputStream rosm;
+		/** Count output stream */
+		private final ConcurrentReadOutputStream rosc;
 		/** Thread ID */
 		final int tid;
 	}
@@ -601,6 +673,9 @@ public class BloomFilterWrapper {
 	private String out1=null;
 	/** Secondary output file path */
 	private String out2=null;
+	
+	/** Output for kmer counts */
+	private String outc=null;
 
 	private String qfout1=null;
 	private String qfout2=null;
@@ -655,6 +730,9 @@ public class BloomFilterWrapper {
 	/** Secondary output file for matching reads */
 	private final FileFormat ffoutm2;
 	
+	/** Output for kmers and counts */
+	private final FileFormat ffoutc;
+	
 	final BloomFilter filter;
 	
 	final int k;
@@ -668,6 +746,11 @@ public class BloomFilterWrapper {
 	final int minCount;
 	float memFraction=1.0f;
 	
+	final int bitsPerBase=BloomFilter.bitsPerBase;
+	final int shift;
+	final int shift2;
+	final long mask;
+	
 	/*--------------------------------------------------------------*/
 	/*----------------        Common Fields         ----------------*/
 	/*--------------------------------------------------------------*/
