@@ -40,7 +40,6 @@ public class ErrorCorrect extends Thread{
 		
 		int k=23;
 		int cbits=4;
-		int gap=0;
 		int hashes=1;
 		int thresh1=1;
 		int thresh2=2;
@@ -72,8 +71,6 @@ public class ErrorCorrect extends Thread{
 				thresh1=Integer.parseInt(b);
 			}else if(a.equals("thresh") || a.equals("thresh2")){
 				thresh2=Integer.parseInt(b);
-			}else if(a.startsWith("gap")){
-				gap=Integer.parseInt(b);
 			}else if(a.startsWith("matrixbits")){
 				matrixbits=Integer.parseInt(b);
 			}else if(a.startsWith("hashes") || a.startsWith("multihash")){
@@ -115,12 +112,13 @@ public class ErrorCorrect extends Thread{
 			Parser.processQuality();
 		}
 		
-		KCountArray kca=makeTable(reads1, reads2, k, cbits, gap, hashes, buildpasses, matrixbits, tablereads, buildStepsize, thresh1, thresh2);
+		KCountArray kca=makeTable(reads1, reads2, k, cbits, hashes, buildpasses, matrixbits, tablereads, buildStepsize, thresh1, thresh2);
 		
 		detect(reads1, reads2, kca, k, thresh2, maxReads, output, ordered, append, overwrite);
 	}
 	
-	public static KCountArray makeTable(String reads1, String reads2, int k, int cbits, int gap, int hashes, int buildpasses, int matrixbits,
+	//Only called by main...
+	public static KCountArray makeTable(String reads1, String reads2, int k, int cbits, int hashes, int buildpasses, int matrixbits,
 			long maxreads, int stepsize, int thresh1, int thresh2){
 		
 		Timer thash=new Timer();
@@ -131,12 +129,11 @@ public class ErrorCorrect extends Thread{
 		
 		thash.start();
 //		Data.sysout.println("kbits="+(kbits)+" -> "+(1L<<kbits)+", matrixbits="+(matrixbits)+" -> "+(1L<<matrixbits)+", cbits="+cbits+", gap="+gap+", hashes="+hashes);
-		KCountArray kca=KCountArray.makeNew(1L<<kbits, 1L<<matrixbits, cbits, gap, hashes);
+		KCountArray kca=KCountArray.makeNew(1L<<matrixbits, cbits, hashes);
 		
-		assert(gap==0) : "TODO";
 		if(buildpasses==1){
 			
-			KmerCount6.count(reads1, reads2, k, cbits, gap, true, kca);
+			KmerCount6.count(reads1, reads2, k, cbits, true, kca);
 			kca.shutdown();
 			
 		}else{
@@ -153,7 +150,7 @@ public class ErrorCorrect extends Thread{
 				kca.shutdown();
 				Data.sysout.println("Trusted:   \t"+kca.toShortString());
 				trusted=kca;
-				kca=KCountArray.makeNew(1L<<kbits, 1L<<matrixbits, cbits, gap, hashes);
+				kca=KCountArray.makeNew(1L<<matrixbits, cbits, hashes);
 				
 			}
 			
@@ -348,11 +345,9 @@ public class ErrorCorrect extends Thread{
 		
 		final int kbits=2*k;
 		final long mask=(kbits>63 ? -1L : ~((-1L)<<kbits));
-		final int gap=kca.gap;
 		final byte[] bases=r.bases;
-		assert(kca.gap==0);
 		
-		int bslen=r.length()-k-gap+1;
+		int bslen=r.length()-k+1;
 		if(bslen<1){return null;} //Read is too short to detect errors
 		BitSet bs=new BitSet(bslen);
 		
@@ -385,13 +380,11 @@ public class ErrorCorrect extends Thread{
 		
 		final int kbits=2*k;
 		final long mask=(kbits>63 ? -1L : ~((-1L)<<kbits));
-		final int gap=kca.gap;
 		final byte[] bases=r.bases;
-		assert(gap==0);
 		
-		if(r.bases==null || r.length()<k+gap){return null;} //Read is too short to detect errors
+		if(r.bases==null || r.length()<k){return null;} //Read is too short to detect errors
 		BitSet bs=new BitSet(r.length());
-		final int setlen=k+gap;
+		final int setlen=k;
 		
 		int len=0;
 		long kmer=0;
@@ -424,14 +417,12 @@ public class ErrorCorrect extends Thread{
 		
 		final int kbits=2*k;
 		final long mask=(kbits>63 ? -1L : ~((-1L)<<kbits));
-		final int gap=kca.gap;
 		final byte[] bases=r.bases;
-		assert(gap==0);
 		
-		if(r.bases==null || r.length()<k+gap){return null;} //Read is too short to detect errors
+		if(r.bases==null || r.length()<k){return null;} //Read is too short to detect errors
 		BitSet bs=new BitSet(r.length());
 		bs.set(0, r.length());
-		final int setlen=k+gap;
+		final int setlen=k;
 		
 		int len=0;
 		long kmer=0;
@@ -461,17 +452,14 @@ public class ErrorCorrect extends Thread{
 	}
 	
 	public static BitSet detectErrorsTips(final Read r, final KCountArray kca, final int k, final int thresh){
-//		if(kca.gap>0){return detectErrorsSplit(r, kca, k, thresh);}
 		
 		final int kbits=2*k;
 		final long mask=(kbits>63 ? -1L : ~((-1L)<<kbits));
-		final int gap=kca.gap;
 		final byte[] bases=r.bases;
-		assert(gap==0);
 		
-		if(r.bases==null || r.length()<k+gap){return null;} //Read is too short to detect errors
+		if(r.bases==null || r.length()<k){return null;} //Read is too short to detect errors
 		BitSet bs=new BitSet(r.length());
-		final int setlen=k+gap;
+		final int setlen=k;
 		
 		int len=0;
 		long kmer=0;
@@ -500,7 +488,6 @@ public class ErrorCorrect extends Thread{
 
 	/** Assumes bulk mode was used; e.g., any '0' bit is covered by no correct kmers */
 	public static BitSet correctErrors(final Read r, final KCountArray kca, final int k, final int thresh, BitSet bs, final int maxCorrections, final int maxBurst){
-		if(kca.gap>0){assert(false) : "TODO";}
 		
 		assert(!OUTPUT_INFO) : "TODO: Outputting correction data is not yet supported.";
 		
@@ -587,8 +574,7 @@ public class ErrorCorrect extends Thread{
 	private static boolean correctFromLeft(Read r, KCountArray kca, int k, int thresh, BitSet bs, int error) {
 		final int kbits=2*k;
 		final long mask=(kbits>63 ? -1L : ~((-1L)<<kbits));
-		final int gap=kca.gap;
-		final int setlen=k+gap;
+		final int setlen=k;
 		final int startLoc=error-(setlen)+1;
 		final byte oldBase=r.bases[error];
 		final byte[] bases=r.bases;
@@ -686,8 +672,7 @@ public class ErrorCorrect extends Thread{
 		final int kbits=2*k;
 		final int shift=kbits-2;
 		final long mask=(kbits>63 ? -1L : ~((-1L)<<kbits));
-		final int gap=kca.gap;
-		final int setlen=k+gap;
+		final int setlen=k;
 		final int stopLoc=error+(setlen)-1;
 		final byte oldBase=r.bases[error];
 		final byte[] bases=r.bases;
