@@ -38,18 +38,22 @@ public abstract class KmerCountAbstract {
 	public static byte minQuality=6;
 	public static long readsProcessed=0;
 	public static long maxReads=-1;
-	public static int BUFFERLEN=500;
 	
 	public static float minProb=0.5f;
 
 	public static long keysCounted=0;
+	public static long increments=0;
 	
-	public static int THREADS=Shared.threads();
 	public static final boolean verbose=false;
 	public static boolean PREJOIN=false;
 	public static boolean CANONICAL=false;
 	public static boolean KEEP_DUPLICATE_KMERS=true;
 	public static boolean SKETCH_MODE=false;
 	public static boolean STORE_HASHED=false;
+	public static boolean BUFFERED=false;
+	public static int BUFFERLEN=3000; //Optimal is in the range of 2000-8000 for Clumpified 2x150bp data.
+//	public static boolean SORT_SERIAL=false; //Not needed, see parallel sort flag
+	
+	public static int maxShortKmerLength=31;
 	
 }
