@@ -3,6 +3,7 @@ package clump;
 import java.io.PrintStream;
 import java.util.ArrayList;
 import java.util.Collections;
+import java.util.HashMap;
 
 import bloom.KCountArray;
 import fileIO.ReadWrite;
@@ -66,7 +67,8 @@ public abstract class KmerSort {
 		
 		String cpstring=""+(groups==1 ? clumpsProcessedThisPass : clumpsProcessedTotal);
 		String epstring=""+correctionsTotal;
-		String dpstring=""+duplicatesTotal;
+		String efstring=""+(entryFiltered);
+		String dpstring=""+(duplicatesTotal + entryFiltered);
 
 		String rostring=""+readsOut;
 		String bostring=""+basesOut;
@@ -79,6 +81,7 @@ public abstract class KmerSort {
 		while(rpstring2.length()<12){rpstring2=" "+rpstring2;}
 		while(cpstring.length()<12){cpstring=" "+cpstring;}
 		while(epstring.length()<12){epstring=" "+epstring;}
+		while(efstring.length()<12){efstring=" "+efstring;}
 		while(dpstring.length()<12){dpstring=" "+dpstring;}
 
 		while(rostring.length()<12){rostring=" "+rostring;}
@@ -92,8 +95,11 @@ public abstract class KmerSort {
 		if(correct){
 			outstream.println("Errors Corrected: "+epstring);
 		}
-		if(dedupe){
+		if(dedupe || entryfilter){
 			outstream.println("Duplicates Found: "+dpstring);
+			if(entryfilter && verbose && false){
+				outstream.println(" -Entry Filtered: "+efstring);
+			}
 			outstream.println("Reads Out:        "+rostring);
 			outstream.println("Bases Out:        "+bostring);
 		}
@@ -271,7 +277,7 @@ public abstract class KmerSort {
 		ArrayList<FetchThread1> alft=new ArrayList<FetchThread1>(threads);
 		for(int i=0; i<threads; i++){alft.add(new FetchThread1(i, cris, kc, unpair));}
 		
-		readsThisPass=memThisPass=0;
+		readsThisPass=memThisPass=entryFilteredThisPass=0;
 		
 		if(verbose){outstream.println("Starting threads.");}
 		for(FetchThread1 ht : alft){ht.start();}
@@ -289,6 +295,7 @@ public abstract class KmerSort {
 					e.printStackTrace();
 				}
 			}
+			entryFilteredThisPass+=ht.entryFilteredT;
 			readsThisPass+=ht.readsProcessedT;
 			basesProcessed+=ht.basesProcessedT;
 			diskProcessed+=ht.diskProcessedT;
@@ -296,24 +303,28 @@ public abstract class KmerSort {
 		}
 		readsProcessed+=readsThisPass;
 		memProcessed+=memThisPass;
+		entryFiltered+=entryFilteredThisPass;
 
 		if(verbose){t.stop("Fetch time: ");}
 		if(verbose){System.err.println("Closing input stream.");}
 		errorState=ReadWrite.closeStream(cris)|errorState;
 		
 		if(verbose){t.start("Combining thread output.");}
-		assert(readsProcessed<=Integer.MAX_VALUE) :
+		long readsLeft=readsThisPass-entryFilteredThisPass;
+		long slotsLeft=cris.paired() && !unpair ? readsLeft/2 : readsLeft;
+		assert(slotsLeft<=Shared.MAX_ARRAY_LEN) :
 			"\nThe number of reads is greater than 2 billion, which is the limit for a single group. "
 			+ "\nPlease rerun and manually specify 'groups=7' or similar, "
 			+ "\nsuch that the number of reads per group is less than 2 billion.";
-		ArrayList<Read> list=new ArrayList<Read>((int)readsThisPass);
+		ArrayList<Read> list=new ArrayList<Read>((int)(slotsLeft));
 		for(int i=0; i<threads; i++){
 			FetchThread1 ft=alft.set(i, null);
 			list.addAll(ft.storage);
 		}
 		if(verbose){t.stop("Combine time: ");}
 		
-		assert(list.size()==readsThisPass || (cris.paired() && list.size()*2==readsThisPass)) : list.size()+", "+readsThisPass+", "+cris.paired();
+		assert(list.size()==slotsLeft) : list.size()+", "+readsThisPass+", "+readsLeft+", "+slotsLeft+", "+cris.paired();
+		//assert(list.size()==readsLeft || (cris.paired() && list.size()*2==readsLeft)) : list.size()+", "+readsThisPass+", "+readsLeft+", "+cris.paired();
 		ecco=false;
 		return list;
 	}
@@ -330,6 +341,7 @@ public abstract class KmerSort {
 			kc=kc_;
 			storage=new ArrayList<Read>();
 			unpairT=unpair_;
+			entryFilterTable=(entryfilter ? new HashMap<Long, Read>() : null);
 		}
 		
 		@Override
@@ -377,6 +389,27 @@ public abstract class KmerSort {
 					}
 				}
 				
+				if(entryFilterTable!=null){
+					int removed=0;
+					for(int i=0; i<reads.size(); i++){
+						Read r=reads.get(i);
+						final long key=Hasher.hashPair(r);
+						final Long key2=Long.valueOf(key);
+						final Read old=entryFilterTable.get(key2);
+						if(old==null){
+							entryFilterTable.put(key2, r);
+						}else{
+							boolean same=Hasher.equalsPaired(r, old);
+							if(same){
+								removed++;
+								entryFilteredT+=r.pairCount();
+								reads.set(i, null);
+							}
+						}
+					}
+					if(removed>0){Tools.condenseStrict(reads);}
+				}
+				
 				ArrayList<Read> hashList=reads;
 				if(paired && unpairT){
 					hashList=new ArrayList<Read>(reads.size()*2);
@@ -394,7 +427,7 @@ public abstract class KmerSort {
 				
 				kc.hash(hashList, table, minCount, true);
 				storage.addAll(hashList);
-				cris.returnList(ln);
+				cris.returnList(ln.id, false);
 				ln=cris.nextList();
 				reads=(ln!=null ? ln.list : null);
 			}
@@ -416,6 +449,8 @@ public abstract class KmerSort {
 		final KmerComparator kc;
 		final ArrayList<Read> storage;
 		final boolean unpairT;
+		final HashMap<Long, Read> entryFilterTable;
+		public long entryFilteredT=0;
 		
 		protected long readsProcessedT=0;
 		protected long basesProcessedT=0;
@@ -488,10 +523,12 @@ public abstract class KmerSort {
 	protected long basesProcessed=0;
 	protected long diskProcessed=0;
 	protected long memProcessed=0;
+	protected static long entryFiltered=0;
 
 	protected long readsOut=0;
 	protected long basesOut=0;
 
+	protected long entryFilteredThisPass=0;
 	protected long readsThisPass=0;
 	protected long memThisPass=0;
 	
@@ -520,7 +557,9 @@ public abstract class KmerSort {
 	boolean unpair=false;
 	boolean repair=false;
 	boolean namesort=false;
+	boolean entryfilter=false;
 	final boolean parallelSort=Shared.parallelSort;
+	boolean memWarned=false;
 	
 	boolean useSharedHeader=false;
 	int reorderMode=REORDER_FALSE;
