@@ -119,6 +119,8 @@ public class KmerSort2 extends KmerSort {
 			
 			else if(a.equals("prefilter")){
 				KmerReduce.prefilter=Parse.parseBoolean(b);
+			}else if(a.equals("entryfilter")){
+				entryfilter=Parse.parseBoolean(b);
 			}else if(a.equals("groups") || a.equals("g") || a.equals("sets") || a.equals("ways")){
 				groups=Integer.parseInt(b);
 				splitInput=(groups>1);
