@@ -3,6 +3,7 @@ package clump;
 import java.io.File;
 import java.util.ArrayList;
 import java.util.Collections;
+import java.util.HashMap;
 import java.util.concurrent.SynchronousQueue;
 import java.util.concurrent.atomic.AtomicInteger;
 
@@ -135,6 +136,8 @@ public class KmerSort3 extends KmerSort {
 			
 			else if(a.equals("prefilter")){
 				KmerReduce.prefilter=Parse.parseBoolean(b);
+			}else if(a.equals("entryfilter")){
+				entryfilter=Parse.parseBoolean(b);
 			}else if(a.equals("groups") || a.equals("g") || a.equals("sets") || a.equals("ways")){
 				groups=Integer.parseInt(b);
 				splitInput=(groups>1);
@@ -531,6 +534,7 @@ public class KmerSort3 extends KmerSort {
 	private long closeFetchThread3s(ArrayList<FetchThread3> alft){
 		readsThisPass=0;
 		memThisPass=0;
+		entryFilteredThisPass=0;
 		/* Wait for threads to die */
 		for(FetchThread3 ft : alft){
 
@@ -542,6 +546,7 @@ public class KmerSort3 extends KmerSort {
 					e.printStackTrace();
 				}
 			}
+			entryFilteredThisPass+=ft.entryFilteredT;
 			readsThisPass+=ft.readsProcessedT;
 			basesProcessed+=ft.basesProcessedT;
 			diskProcessed+=ft.diskProcessedT;
@@ -549,6 +554,7 @@ public class KmerSort3 extends KmerSort {
 			
 			errorState|=ft.errorStateT;
 		}
+		entryFiltered+=entryFilteredThisPass;
 		readsProcessed+=readsThisPass;
 		memProcessed+=memThisPass;
 		
@@ -627,27 +633,46 @@ public class KmerSort3 extends KmerSort {
 //					outstream.println("totalMem="+totalMem+", Shared.memFree()="+Shared.memFree()+", Shared.memUsed()="+Shared.memUsed());
 //					outstream.println("fileSize="+fileSize+", "+"fileMem="+fileMem+", "+"memRatio="+memRatio+", ");
 //					outstream.println((size-1000>expectedSizePerGroup*3)+", "+(expectedMem*3>totalMem));
-					
+
 					//TODO: This could also be based on the number of FetchThreads.
-					
 					if(expectedMem>0.3*totalMem && (fileMem<1 || fileMem>0.8*totalMem)){
-						outstream.println("\n***  Warning  ***\n"
-								+ "A temp file may be too big to store in memory, due to uneven splitting:");
+						synchronized(this.getClass()){
+							if(!memWarned){
+								outstream.println("\n***  Warning  ***\n"
+										+ "A temp file may be too big to store in memory, due to uneven splitting:");
 
-						outstream.println("expectedMem="+((long)expectedMem)+", fileMem="+fileMem+", available="+totalMem);
-
-						if(repair || namesort){
-							outstream.println("It cannot be streamed to output unaltered because "+(namesort ? " namesort=t" : "repair=t"));
-							outstream.println("If this causes the program to crash, please re-run with more memory or groups.\n");
-						}else{
-							outstream.println(
-									"It will be streamed to output unaltered.\n"
-											+ "To avoid this behavior, increase memory or increase groups.\n"
-											+ "Set the flag forceprocess=t to disable this check.\n");
-//							Timer t=new Timer();
-							ArrayList<Read> list=streamNext_inner(cris);
-//							t.stop("Stream time: ");
-							return list;
+								outstream.println("expectedMem="+((long)expectedMem)+", fileMem="+fileMem+", available="+totalMem);
+							}
+							if(entryfilter){
+								if(!memWarned){
+									outstream.println(
+											"If the program crashes, increase memory or manually increase groups.\n");
+								}
+							}else if(dedupe & !Clump.opticalOnly){
+								if(!memWarned){
+									outstream.println(
+											"entryfilter is automatically being set to true to reduce memory load while removing duplicates.\n"
+													+"If the program crashes, increase memory or manually increase groups.\n");
+								}
+								entryfilter=true;
+							}else if(repair || namesort){
+								if(!memWarned){
+									outstream.println("It cannot be streamed to output unaltered because "+(namesort ? " namesort=t" : "repair=t"));
+									outstream.println("If this causes the program to crash, please re-run with more memory or groups.\n");
+								}
+							}else{
+								if(!memWarned){
+									outstream.println(
+											"It will be streamed to output unaltered.\n"
+													+ "To avoid this behavior, increase memory or increase groups.\n"
+													+ "Set the flag forceprocess=t to disable this check.\n");
+								}
+								//							Timer t=new Timer();
+								ArrayList<Read> list=streamNext_inner(cris);
+								//							t.stop("Stream time: ");
+								return list;
+							}
+							memWarned=true;
 						}
 					}
 				}
@@ -673,7 +698,7 @@ public class KmerSort3 extends KmerSort {
 //			if(verbose){t.start("Making hash threads.");}
 			final int subthreads=Tools.mid(1, Shared.threads()/2, 8);
 			ArrayList<FetchSubThread> alht=new ArrayList<FetchSubThread>(subthreads);
-			long readsThisGroup=0, memThisGroup=0;
+			long readsThisGroup=0, memThisGroup=0, entryFilteredThisGroup=0;
 			for(int i=0; i<subthreads; i++){alht.add(new FetchSubThread(i, cris, kc, unpair));}
 			
 //			if(verbose){outstream.println("Starting threads.");}
@@ -691,11 +716,13 @@ public class KmerSort3 extends KmerSort {
 						e.printStackTrace();
 					}
 				}
+				entryFilteredThisGroup+=ht.entryFilteredT;
 				readsThisGroup+=ht.readsProcessedST;
 				basesProcessedT+=ht.basesProcessedST;
 				diskProcessedT+=ht.diskProcessedST;
 				memThisGroup+=ht.memProcessedST;
 			}
+			entryFilteredT+=entryFilteredThisGroup;
 			readsProcessedT+=readsThisGroup;
 			memProcessedT+=memThisGroup;
 
@@ -704,13 +731,15 @@ public class KmerSort3 extends KmerSort {
 			errorStateT=ReadWrite.closeStream(cris)|errorStateT;
 			
 //			if(verbose){t.start("Combining thread output.");}
-			assert(readsProcessedT<=Integer.MAX_VALUE && readsProcessedT>=0);
-			ArrayList<Read> list=new ArrayList<Read>((int)readsThisGroup);
+			long readsLeft=readsThisGroup-entryFilteredThisGroup;
+			long slotsLeft=cris.paired() && !unpair ? readsLeft/2 : readsLeft;
+			assert(slotsLeft<=Shared.MAX_ARRAY_LEN && readsProcessedT>=0);
+			ArrayList<Read> list=new ArrayList<Read>((int)slotsLeft);
 			for(int i=0; i<subthreads; i++){
 				FetchSubThread ht=alht.set(i, null);
 				list.addAll(ht.storage);
 			}
-			assert(list.size()==readsThisGroup || (cris.paired() && list.size()*2==readsThisGroup)) : list.size()+", "+readsThisGroup+", "+cris.paired();
+			assert(list.size()==slotsLeft) : list.size()+", "+readsThisGroup+", "+slotsLeft+", "+cris.paired();
 //			if(verbose){t.stop("Combine time: ");}
 			
 //			if(verbose){t.start("Sorting.");}
@@ -724,7 +753,8 @@ public class KmerSort3 extends KmerSort {
 		final AtomicInteger nextGroup;
 		final KmerComparator kc;
 		final ConcurrentReadOutputStream[] rosa;
-		
+
+		protected long entryFilteredT=0;
 		protected long readsProcessedT=0;
 		protected long basesProcessedT=0;
 		protected long diskProcessedT=0;
@@ -740,6 +770,7 @@ public class KmerSort3 extends KmerSort {
 				kcT=kc_;
 				storage=new ArrayList<Read>();
 				unpairT=unpair_;
+				entryFilterTable=(entryfilter ? new HashMap<Long, Read>() : null);
 			}
 			
 			@Override
@@ -783,6 +814,27 @@ public class KmerSort3 extends KmerSort {
 						}
 					}
 					
+					if(entryFilterTable!=null){
+						int removed=0;
+						for(int i=0; i<reads.size(); i++){
+							Read r=reads.get(i);
+							final long key=Hasher.hashPair(r);
+							final Long key2=Long.valueOf(key);
+							final Read old=entryFilterTable.get(key2);
+							if(old==null){
+								entryFilterTable.put(key2, r);
+							}else{
+								boolean same=Hasher.equalsPaired(r, old);
+								if(same){
+									removed++;
+									entryFilteredT+=r.pairCount();
+									reads.set(i, null);
+								}
+							}
+						}
+						if(removed>0){Tools.condenseStrict(reads);}
+					}
+					
 					ArrayList<Read> hashList=reads;
 					if(paired && unpairT){
 						hashList=new ArrayList<Read>(reads.size()*2);
@@ -800,7 +852,7 @@ public class KmerSort3 extends KmerSort {
 					
 					kcT.hash(hashList, table, minCount, true);
 					storage.addAll(hashList);
-					cris.returnList(ln);
+					cris.returnList(ln.id, false);
 					ln=cris.nextList();
 					reads=(ln!=null ? ln.list : null);
 				}
@@ -822,6 +874,8 @@ public class KmerSort3 extends KmerSort {
 			final KmerComparator kcT;
 			final ArrayList<Read> storage;
 			final boolean unpairT;
+			final HashMap<Long, Read> entryFilterTable;
+			public long entryFilteredT=0;
 
 			protected long readsProcessedST=0;
 			protected long basesProcessedST=0;
