@@ -5,7 +5,7 @@ import java.io.PrintStream;
 import java.util.ArrayList;
 
 import bloom.KCountArray;
-import bloom.KmerCount7MTA;
+import bloom.ReadCounter;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
@@ -167,7 +167,8 @@ public class PivotSet {
 		int filterHashes=2;
 		float fraction=0.1f;
 		long cells=getCells(fraction, cbits);
-		KCountArray kca=KmerCount7MTA.makeKca(null, null, null, k, cbits, 0, cells, filterHashes, 0, true, ecco, false, maxReads, 1, 1, 1, 1, null, 0, amino);
+		ReadCounter rc=new ReadCounter(k, true, ecco, false, amino);
+		KCountArray kca=rc.makeKca(null, null, null, cbits, cells, filterHashes, 0, maxReads, 1, 1, 1, 1, null, 0);
 		
 		final ConcurrentReadInputStream cris;
 		{
@@ -211,7 +212,8 @@ public class PivotSet {
 		int filterHashes=2;
 		float fraction=0.1f;
 		long cells=getCells(fraction, cbits);
-		KCountArray kca=KmerCount7MTA.makeKca(null, null, null, k, cbits, 0, cells, filterHashes, 0, true, false, false, -1, 1, 1, 1, 1, null, 0, amino);
+		ReadCounter rc=new ReadCounter(k, true, false, false, amino);
+		KCountArray kca=rc.makeKca(null, null, null, cbits, cells, filterHashes, 0, -1, 1, 1, 1, 1, null, 0);
 		
 		if(verbose){System.err.println("Making hash threads.");}
 		final int threads=Shared.threads();
