@@ -10,6 +10,7 @@ import java.util.concurrent.atomic.AtomicLongArray;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -102,7 +103,7 @@ public class FixScaffoldGaps implements Accumulator<FixScaffoldGaps.ProcessThrea
 		
 		{
 //			if("auto".equalsIgnoreCase(atomic)){Scaffold.setCA3A(Shared.threads()>8);}
-//			else{Scaffold.setCA3A(Tools.parseBoolean(atomic));}
+//			else{Scaffold.setCA3A(Parse.parseBoolean(atomic));}
 			samFilter.setSamtoolsFilter();
 			
 			streamerThreads=Tools.max(1, Tools.min(streamerThreads, Shared.threads()));
@@ -146,13 +147,13 @@ public class FixScaffoldGaps implements Accumulator<FixScaffoldGaps.ProcessThrea
 			if(b!=null && b.equalsIgnoreCase("null")){b=null;}
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ref") || a.equals("scaffolds")){
 				ref=b;
 			}else if(a.equals("insertlist")){
 				insertList=b;
 			}else if(a.equals("ordered")){
-				ordered=Tools.parseBoolean(b);
+				ordered=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("ns") || a.equalsIgnoreCase("n") || a.equalsIgnoreCase("scaffoldbreak") || a.equalsIgnoreCase("gap")){
 				scaffoldBreakNs=Integer.parseInt(b);
 				assert(scaffoldBreakNs>0);
@@ -163,11 +164,11 @@ public class FixScaffoldGaps implements Accumulator<FixScaffoldGaps.ProcessThrea
 				trimFraction=Float.parseFloat(b);
 				assert(trimFraction>=0 && trimFraction<=1) : "trimFraction should be between 0 and 1";
 			}else if(a.equals("clearfilters") || a.equals("clearfilter")){
-				if(Tools.parseBoolean(b)){
+				if(Parse.parseBoolean(b)){
 					samFilter.clear();
 				}
 			}else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(samFilter.parse(arg, a, b)){
 				//do nothing
