@@ -204,6 +204,9 @@ public final class AminoAcid {
 
 	/** Element i is: 0 for 'A', 1 for 'C', 2 for 'G', 3 for 'T', 0 otherwise */
 	public static final byte[] baseToNumber0=new byte[128];
+
+	/** Element i is: 0 for 'A', 1 for 'C', 2 for 'G', 3 for 'T', 3 otherwise */
+	public static final byte[] baseToNumber3=new byte[128];
 	
 	/** Element i is: 3 for 'A', 2 for 'C', 1 for 'G', 0 for 'T', -1 otherwise */
 	public static final byte[] baseToComplementNumber=new byte[128];
@@ -220,6 +223,10 @@ public final class AminoAcid {
 	/** Element i is: 0 for 'A', 1 for 'C', 2 for 'G', 3 for 'T', 4 otherwise */
 	public static final byte[] baseToNumberACGTother=new byte[128];
 	
+	/** Element i is: 0 for empty, 1-26 for A-Z, plus "*-"; otherwise, 31.
+	 * Allows fast alphabetical sorting of sequences. */
+	public static final byte[] symbolTo5Bit=new byte[128];
+	
 	/** A>A, C>C, G>G, T/U>T, other>N */
 	public static final byte[] baseToACGTN=new byte[128];
 	
@@ -754,7 +761,6 @@ public final class AminoAcid {
 		
 		
 		Arrays.fill(baseToACGTN, (byte)'N');
-		
 		Arrays.fill(baseToNumberExtended, (byte)-1);
 		for(int i=0; i<numberToBaseExtended.length; i++){
 			char x=(char)numberToBaseExtended[i];
@@ -786,15 +792,17 @@ public final class AminoAcid {
 
 		Arrays.fill(baseToNumber, (byte)-1);
 		Arrays.fill(baseToNumber0, (byte)0);
+		Arrays.fill(baseToNumber3, (byte)3);
 		for(int i=0; i<numberToBase.length; i++){
 			char x=(char)numberToBase[i];
 			if(x=='A' || x=='C' || x=='G' || x=='T'){
-				baseToNumber0[x]=baseToNumber[x]=(byte)i;
-				baseToNumber0[Tools.toLowerCase(x)]=baseToNumber[Tools.toLowerCase(x)]=(byte)i;
+				int x2=Tools.toLowerCase(x);
+				baseToNumber3[x]=baseToNumber0[x]=baseToNumber[x]=(byte)i;
+				baseToNumber3[x2]=baseToNumber0[x2]=baseToNumber[x2]=(byte)i;
 			}
 		}
-		baseToNumber0['U']=baseToNumber['U']=3;
-		baseToNumber0['u']=baseToNumber['u']=3;
+		baseToNumber3['U']=baseToNumber0['U']=baseToNumber['U']=3;
+		baseToNumber3['u']=baseToNumber0['u']=baseToNumber['u']=3;
 		
 		Arrays.fill(baseToComplementNumber, (byte)-1);
 		baseToComplementNumber['A']=baseToComplementNumber['a']=3;
@@ -952,6 +960,10 @@ public final class AminoAcid {
 			}
 		}
 		
+		Arrays.fill(symbolTo5Bit, (byte)31);
+		for(int i=0; i<26; i++){symbolTo5Bit['A'+i]=symbolTo5Bit['a'+i]=(byte)(i+1);}
+		symbolTo5Bit['*']=27;
+		symbolTo5Bit['-']=28;
 	}
 	
 }
