@@ -10,6 +10,7 @@ import fileIO.ByteFile1;
 import fileIO.ByteFile2;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -67,7 +68,7 @@ public class FilterReadsByName {
 			String b=split.length>1 ? split[1] : null;
 
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
@@ -88,35 +89,35 @@ public class FilterReadsByName {
 				}else if(b.equals("name")){
 					nameSubstringOfHeader=true;
 				}else{
-					nameSubstringOfHeader=headerSubstringOfName=Tools.parseBoolean(b);
+					nameSubstringOfHeader=headerSubstringOfName=Parse.parseBoolean(b);
 				}
 			}else if(a.equals("casesensitive") || a.equals("case")){
-				ignoreCase=!Tools.parseBoolean(b);
+				ignoreCase=!Parse.parseBoolean(b);
 			}else if(a.equals("include") || a.equals("retain")){
-				exclude=!Tools.parseBoolean(b);
+				exclude=!Parse.parseBoolean(b);
 			}else if(a.equals("exclude") || a.equals("remove")){
-				exclude=Tools.parseBoolean(b);
+				exclude=Parse.parseBoolean(b);
 			}else if(a.equals("prefix") || a.equals("prefixmode")){
-				prefixmode=Tools.parseBoolean(b);
+				prefixmode=Parse.parseBoolean(b);
 			}else if(a.equals("minlen") || a.equals("minlength")){
-				minLength=Tools.parseIntKMG(b);
+				minLength=Parse.parseIntKMG(b);
 			}else if(a.equals("from")){
-				fromPos=Tools.parseIntKMG(b);
+				fromPos=Parse.parseIntKMG(b);
 			}else if(a.equals("to")){
-				toPos=Tools.parseIntKMG(b);
+				toPos=Parse.parseIntKMG(b);
 			}else if(a.equals("pos") || a.equals("range")){
 				assert(b!=null) : "Bad parameter: "+arg;
 				String[] split2=b.split("-");
-				fromPos=Tools.parseIntKMG(split2[0]);
-				toPos=Tools.parseIntKMG(split2[1]);
+				fromPos=Parse.parseIntKMG(split2[0]);
+				toPos=Parse.parseIntKMG(split2[1]);
 			}else if(a.equals("truncate")){
-				trimWhitespace=truncateHeaderSymbol=Tools.parseBoolean(b);
+				trimWhitespace=truncateHeaderSymbol=Parse.parseBoolean(b);
 			}else if(a.equals("truncatewhitespace") || a.equals("tws")){
-				trimWhitespace=Tools.parseBoolean(b);
+				trimWhitespace=Parse.parseBoolean(b);
 			}else if(a.equals("truncateheadersymbol") || a.equals("ths")){
-				truncateHeaderSymbol=Tools.parseBoolean(b);
+				truncateHeaderSymbol=Parse.parseBoolean(b);
 			}else if(a.equals("ignoreafterwhitespace") || a.equals("iaw")){
-//				ignoreAfterWhitespace=Tools.parseBoolean(b);
+//				ignoreAfterWhitespace=Parse.parseBoolean(b);
 			}else if(parser.in1==null && i==0 && !arg.contains("=") && (arg.toLowerCase().startsWith("stdin") || new File(arg).exists())){
 				parser.in1=arg;
 			}else if(parser.parse(arg, a, b)){
