@@ -566,7 +566,7 @@ public class ByteStreamWriter extends Thread {
 		return this;
 	}
 	
-	public ByteStreamWriter printKmer(long kmer, int count, int k){
+	public ByteStreamWriter printKmer(long kmer, long count, int k){
 		AbstractKmerTable.toBytes(kmer, count, k, buffer);
 		flushBuffer(false);
 		return this;
@@ -578,7 +578,7 @@ public class ByteStreamWriter extends Thread {
 		return this;
 	}
 	
-	public ByteStreamWriter printKmer(long[] array, int count, int k){
+	public ByteStreamWriter printKmer(long[] array, long count, int k){
 		AbstractKmerTableU.toBytes(array, count, k, buffer);
 		flushBuffer(false);
 		return this;
@@ -590,6 +590,12 @@ public class ByteStreamWriter extends Thread {
 		return this;
 	}
 	
+//	public ByteStreamWriter printKmer(long kmer, long[] values, int k){
+//		kmer64.AbstractKmerTable64.toBytes(kmer, values, k, buffer);
+//		flushBuffer(false);
+//		return this;
+//	}
+	
 	
 	/*--------------------------------------------------------------*/
 	/*----------------           Println            ----------------*/
@@ -621,6 +627,12 @@ public class ByteStreamWriter extends Thread {
 	public ByteStreamWriter println(Read r){print(r); return print('\n');}
 	public ByteStreamWriter println(Contig c){print(c); return print('\n');}
 
+	public ByteStreamWriter printlnKmer(long kmer, long count, int k){printKmer(kmer, count, k); return print('\n');}
+//	public ByteStreamWriter printlnKmer(long kmer, long[] values, int k){printKmer(kmer, values, k); return print('\n');}
+	public ByteStreamWriter printlnKmer(long[] array, long count, int k){printKmer(array, count, k); return print('\n');}
+//	public ByteStreamWriter printlnKmer(long[] array, long[] values, int k){printKmer(array, values, k); return print('\n');}
+	
+
 	
 	public ByteStreamWriter println(Read r, boolean paired){
 		println(r);
