@@ -930,7 +930,10 @@ public class ReadWrite {
 					failed=true;
 				}
 			}
-			if(failed){throw new RuntimeException("Can't find file "+fname);}
+//			if(failed){throw new RuntimeException("Can't find file "+fname);}
+			if(failed){
+				shared.KillSwitch.exceptionKill(new RuntimeException("Can't find file "+fname));
+			}
 		}
 		
 //		System.err.println("Getting input stream for "+fname);
