@@ -15,6 +15,7 @@ import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import prok.PGMTools;
 import prok.ProkObject;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -121,12 +122,12 @@ public class CutGff implements Accumulator<CutGff.ProcessThread>  {
 				assert(b!=null);
 				Tools.addFiles(b, gffList);
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ReadWrite.verbose=verbose;
 			}else if(a.equals("alignribo") || a.equals("align")){
-				alignRibo=Tools.parseBoolean(b);
+				alignRibo=Parse.parseBoolean(b);
 			}else if(a.equals("adjustendpoints")){
-				adjustEndpoints=Tools.parseBoolean(b);
+				adjustEndpoints=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("slop16s") || a.equalsIgnoreCase("16sslop") || a.equalsIgnoreCase("ssuslop")){
 				ssuSlop=Integer.parseInt(b);
 			}else if(a.equalsIgnoreCase("slop23s") || a.equalsIgnoreCase("23sslop") || a.equalsIgnoreCase("lsuslop")){
@@ -136,7 +137,7 @@ public class CutGff implements Accumulator<CutGff.ProcessThread>  {
 			}else if(a.equalsIgnoreCase("maxnrate") || a.equalsIgnoreCase("maxnfraction")){
 				maxNFraction=Integer.parseInt(b);
 			}else if(a.equals("invert")){
-				invert=Tools.parseBoolean(b);
+				invert=Parse.parseBoolean(b);
 			}else if(a.equals("type") || a.equals("types")){
 				types=b;
 			}else if(a.equals("attributes") || a.equals("requiredattributes")){
@@ -144,11 +145,11 @@ public class CutGff implements Accumulator<CutGff.ProcessThread>  {
 			}else if(a.equals("banattributes") || a.equals("bannedattributes")){
 				bannedAttributes=b.split(",");
 			}else if(a.equals("banpartial")){
-				banPartial=Tools.parseBoolean(b);
+				banPartial=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equalsIgnoreCase("renameByTaxID")){
-				renameByTaxID=Tools.parseBoolean(b);
+				renameByTaxID=Parse.parseBoolean(b);
 			}else if(a.equals("taxmode")){
 				if("accession".equalsIgnoreCase(b)){
 					taxMode=ACCESSION_MODE;
@@ -162,11 +163,11 @@ public class CutGff implements Accumulator<CutGff.ProcessThread>  {
 					assert(false) : "Bad tax mode: "+b;
 				}
 			}else if(a.equals("requirepresent")){
-				requirePresent=Tools.parseBoolean(b);
+				requirePresent=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("onePerFile")){
-				onePerFile=Tools.parseBoolean(b);
+				onePerFile=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("pickBest") || a.equalsIgnoreCase("findBest") || a.equalsIgnoreCase("keepBest")){
-				pickBest=Tools.parseBoolean(b);
+				pickBest=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("minlen")){
@@ -565,7 +566,7 @@ public class CutGff implements Accumulator<CutGff.ProcessThread>  {
 			return null;
 		}
 //		
-//		int[] coords=new int[2];
+//		int[] coords=KillSwitch.allocInt1D(2);
 //		float id1=align(universal, scaf, a, b, minIdentity, coords);
 //		final int rstart=coords[0], rstop=coords[1];
 //		//				assert(false) : rstart+", "+rstop+", "+(rstop-rstart+1)+", "+start+", "+stop;
