@@ -11,6 +11,7 @@ import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -76,7 +77,7 @@ public class IceCreamMaker {
 		ReadWrite.MAX_ZIP_THREADS=Shared.threads();
 		FASTQ.TEST_INTERLEAVED=FASTQ.FORCE_INTERLEAVED=false;
 		Shared.FAKE_QUAL=8;
-		Shared.FASTA_WRAP=511;
+//		Shared.FASTA_WRAP=511;
 		SamLine.SET_FROM_OK=true;
 		
 		{//Parse the arguments
@@ -136,7 +137,7 @@ public class IceCreamMaker {
 			if(b!=null && b.equalsIgnoreCase("null")){b=null;}
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("idhist")){
@@ -144,19 +145,19 @@ public class IceCreamMaker {
 			}
 			
 			else if(a.equals("minlength") || a.equals("minlen")){
-				minMoleculeLength=Tools.parseIntKMG(b);
+				minMoleculeLength=Parse.parseIntKMG(b);
 			}else if(a.equals("maxlength") || a.equals("maxlen")){
-				maxMoleculeLength=Tools.parseIntKMG(b);
+				maxMoleculeLength=Parse.parseIntKMG(b);
 			}else if(a.equals("length") || a.equals("len")){
-				minMoleculeLength=maxMoleculeLength=Tools.parseIntKMG(b);
+				minMoleculeLength=maxMoleculeLength=Parse.parseIntKMG(b);
 			}
 			
 			else if(a.equals("minmovie") || a.equals("minmov")){
-				minMovie=Tools.parseIntKMG(b);
+				minMovie=Parse.parseIntKMG(b);
 			}else if(a.equals("maxmovie") || a.equals("maxmov")){
-				maxMovie=Tools.parseIntKMG(b);
+				maxMovie=Parse.parseIntKMG(b);
 			}else if(a.equals("movie") || a.equals("mov")){
-				minMovie=maxMovie=Tools.parseIntKMG(b);
+				minMovie=maxMovie=Parse.parseIntKMG(b);
 			}
 			
 			else if(a.equals("missingrate") || a.equals("missing")){
@@ -166,7 +167,7 @@ public class IceCreamMaker {
 				hiddenRate=Double.parseDouble(b);
 				assert(hiddenRate<=1);
 			}else if(a.equals("bothends")){
-				allowBothEndsBad=Tools.parseBoolean(b);
+				allowBothEndsBad=Parse.parseBoolean(b);
 				assert(false) : "TODO";
 			}
 			
@@ -174,26 +175,26 @@ public class IceCreamMaker {
 				genomeGC=(float)Double.parseDouble(b);
 				assert(genomeGC>=0 && genomeGC<=1);
 			}else if(a.equals("genomesize")){
-				genomeSize=Tools.parseKMG(b);
+				genomeSize=Parse.parseKMG(b);
 			}else if(a.equals("addns") || a.equals("ns")){
-				addNs=Tools.parseBoolean(b);
+				addNs=Parse.parseBoolean(b);
 			}else if(a.equals("seed")){
 				seed=Long.parseLong(b);
 			}else if(a.equals("zmws") || a.equals("maxzmws") || a.equals("reads")){
-				maxZMWs=Tools.parseIntKMG(b);
+				maxZMWs=Parse.parseIntKMG(b);
 			}else if(a.equals("ccs")){
-				makeCCS=Tools.parseBoolean(b);
+				makeCCS=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("invertedrepeatrate") || a.equals("invertrepeatrate") || a.equals("irrate")){
 				invertedRepeatRate=Double.parseDouble(b);
 				assert(invertedRepeatRate>=0);
 			}else if(a.equals("invertedrepeatminlen") || a.equals("invertrepeatminlen") || a.equals("irminlen")){
-				invertedRepeatMinLength=Tools.parseIntKMG(b);
+				invertedRepeatMinLength=Parse.parseIntKMG(b);
 			}else if(a.equals("invertedrepeatmaxlen") || a.equals("invertrepeatmaxlen") || a.equals("irmaxlen")){
-				invertedRepeatMaxLength=Tools.parseIntKMG(b);
+				invertedRepeatMaxLength=Parse.parseIntKMG(b);
 			}else if(a.equals("invertedrepeatlen") || a.equals("invertrepeatlen") || a.equals("irlen")){
-				invertedRepeatMinLength=invertedRepeatMaxLength=Tools.parseIntKMG(b);
+				invertedRepeatMinLength=invertedRepeatMaxLength=Parse.parseIntKMG(b);
 			}
 			
 			else if(a.equals("miner") || a.equals("minerrorrate")){
@@ -217,11 +218,13 @@ public class IceCreamMaker {
 				minErrorRate=maxErrorRate=1-(float)Double.parseDouble(b);
 				assert(minErrorRate>=0 && minErrorRate<=1);
 			}else if(a.equals("adderrors")){
-				addErrors=Tools.parseBoolean(b);
+				addErrors=Parse.parseBoolean(b);
+			}else if(a.equals("ref")){
+				parser.in1=b;
 			}
 			
 			else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
 				//do nothing
@@ -491,12 +494,19 @@ public class IceCreamMaker {
 			
 			for(Read r : ln){
 				
+//				System.err.println("Fetched read len="+r.length());//123
+				
 				//Increment counters
 				readsProcessed+=r.pairCount();
 				basesProcessed+=r.pairLength();
 				
+				
+
+//				System.err.println("Filter: addNs="+addNs+", (r.length()>maxMoleculeLength && (invertedRepeatRate<=0 || r.length()>2*invertedRepeatMaxLength);//123
+				
+				//Filter disabled; it causes short sequences to be ignored.
 				//Optional filter criteria
-				if(!addNs || (r.length()>maxMoleculeLength && (invertedRepeatRate<=0 || r.length()>2*invertedRepeatMaxLength))){
+//				if(!addNs || (r.length()>maxMoleculeLength && (invertedRepeatRate<=0 || r.length()>2*invertedRepeatMaxLength))){
 					final byte[] bases=r.bases;
 					
 					if(addNs){
@@ -511,16 +521,19 @@ public class IceCreamMaker {
 					
 					if(bb.length()+bases.length<=MAX_GENOME_LENGTH){
 						bb.append(bases);
+//						System.err.println("Appended "+r.length());//123
 					}else{
+//						System.err.println("Appending partial.");//123
 						for(byte b : bases){
 							bb.append(b);
 							if(bb.length>=MAX_GENOME_LENGTH){
 								cris.returnList(ln.id, true);
+//								System.err.println("Returning partial "+bb.length);//123
 								return bb.toBytes();
 							}
 						}
 					}
-				}
+//				}
 			}
 
 			//Notify the input stream that the list was used
@@ -535,7 +548,8 @@ public class IceCreamMaker {
 		if(ln!=null){
 			cris.returnList(ln.id, ln.list==null || ln.list.isEmpty());
 		}
-		
+
+//		System.err.println("Returning full "+bb.length);//123
 		return bb.toBytes();
 	}
 	
@@ -661,6 +675,10 @@ public class IceCreamMaker {
 			final float errorRate=randomRate(minErrorRate, maxErrorRate, randy);
 			
 			ArrayList<ReadBuilder> baseCalls=baseCallAllPasses(movieLength, errorRate, nextID);
+			if(baseCalls==null){
+//				System.err.println(movieLength+", "+errorRate+", "+nextID);//123
+				return null;
+			}
 			
 			final boolean missing=randy.nextFloat()<missingRate;
 			if(missing){
@@ -736,11 +754,15 @@ public class IceCreamMaker {
 				frag=fetchBases(ref);
 			}
 			
-			if(frag==null){return null;}
+			if(frag==null){
+//				System.err.println("Failed baseCallAllPasses("+movieLength+", "+errorRate+", "+zmw);//123
+				return null;
+			}
 			
 			ArrayList<ReadBuilder> list=new ArrayList<ReadBuilder>();
 			int movieRemaining=movieLength;
 			int moviePos=0;
+			assert(frag.length>0) : frag.length;
 			int start=randy.nextInt(frag.length);
 			while(movieRemaining>0){
 				ReadBuilder rb=baseCallOnePass(frag, errorRate, start, moviePos, movieRemaining, zmw);
@@ -802,13 +824,17 @@ public class IceCreamMaker {
 		private byte[] fetchBases(byte[] source){
 			
 			final int len=randomLength(minMoleculeLength, maxMoleculeLength, randy);
-			int start=randy.nextInt(source.length-len);
-			int stop=start+len;
+			int start=len>=source.length ? 0 : randy.nextInt(source.length-len);
+			int stop=Tools.min(start+len, source.length);
+			
+//			System.err.println("fetchBases(len="+len+", slen="+source.length+", start="+start+", stop="+stop);//123
+			
 			for(int i=start; i<stop; i++){
 				if(!AminoAcid.isFullyDefined(source[i])){
 					return null;
 				}
 			}
+			if(stop-start<1){return null;}
 			byte[] frag=Arrays.copyOfRange(source, start, stop);
 			if(randy.nextBoolean()){AminoAcid.reverseComplementBasesInPlace(frag);}
 			return frag;
