@@ -123,6 +123,8 @@ public final class AssemblyStats2 {
 					if(GCFORMAT<0 || GCFORMAT>5){
 						throw new RuntimeException("\nUnknown gcformat: "+GCFORMAT+"; valid values are 0 through 5.\n");
 					}
+				}else if(a.equals("gcfraction")){
+					GC_FRACTION=Parse.parseBoolean(b);
 				}else if(a.equals("cutoff")){
 					cutoff=Parse.parseKMG(b);
 				}else if(a.equals("k") || a.equals("bbmapkmer")){
@@ -1908,8 +1910,12 @@ public final class AssemblyStats2 {
 			return sb.append(String.format(Locale.ROOT, "%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\n",
 					a*invDef, c*invDef, g*invDef, t*invDef, (g+c)*invDef, gc_std)).toString();
 		}else if(GCFORMAT==0 || GCFORMAT==1 || GCFORMAT==3 || GCFORMAT==4 || GCFORMAT==5){
+			if(GC_FRACTION){
 			return sb.append(String.format(Locale.ROOT, "%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\t%.4f\n",
 					a*invDef, c*invDef, g*invDef, t*invDef, n*invAll, iupacD, otherD, (g+c)*invDef, gc_std)).toString();
+			}
+			return sb.append(String.format(Locale.ROOT, "%d\t%d\t%d\t%d\t%d\t%d\t%d\t%.4f\t%.4f\n",
+					a, c, g, t, n, iupac, other, (g+c)*invDef, gc_std)).toString();
 		}else if(GCFORMAT==2){
 			return sb.append(String.format(Locale.ROOT, "%.4f\t%.4f\n", (g+c)*invDef, gc_std)).toString();
 		}else{
@@ -2060,6 +2066,7 @@ public final class AssemblyStats2 {
 	
 	private static final byte[] charToNum=makeCharToNum();
 	public static int GCFORMAT=1;
+	public static boolean GC_FRACTION=true;
 	public static int FORMAT=1;
 	private static long cutoff=1000000;
 	
