@@ -801,7 +801,7 @@ public final class BBMergeOverlapper {
 
 			//Update kmers
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 
 			//Handle Ns
 			if(x<0){
