@@ -233,8 +233,7 @@ public class CountGC {
 		}
 		
 		if(tsw!=null){
-			tsw.poison();
-			tsw.waitForFinish();
+			tsw.poisonAndWait();
 		}
 		LIMSUM=limsum;
 		return overall;
@@ -334,8 +333,7 @@ public class CountGC {
 		}
 		
 		if(tsw!=null){
-			tsw.poison();
-			tsw.waitForFinish();
+			tsw.poisonAndWait();
 		}
 		LIMSUM=limsum;
 		return overall;
