@@ -733,8 +733,7 @@ public class CoveragePileup {
 			}
 		}
 		
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 	}
 	
 	
