@@ -17,6 +17,7 @@ import fileIO.ByteFile2;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import fileIO.TextFile;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -87,7 +88,7 @@ public class DecontaminateByNormalization {
 			}else if(parser.parseMapping(arg, a, b)){
 				//do nothing
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 				ByteFile1.verbose=verbose;
 				ByteFile2.verbose=verbose;
 				stream.FastaReadInputStream.verbose=verbose;
@@ -121,17 +122,17 @@ public class DecontaminateByNormalization {
 			}else if(a.equals("windowcov")){
 				CoveragePileup.LOW_COV_DEPTH=Double.parseDouble(b);
 			}else if(a.equals("mapraw")){
-				mapRawReads=Tools.parseBoolean(b);
+				mapRawReads=Parse.parseBoolean(b);
 			}
 			
 			/* Tadpole parameters */
 			else if(a.equals("tadpole") || a.equals("ecctadpole") || a.equals("ecct") || a.equals("ecc")){
-				ecct=Tools.parseBoolean(b);
+				ecct=Parse.parseBoolean(b);
 			}else if(a.equals("tadpoleaggressive") || a.equals("aggressive") || a.equals("aecc")){
-				tadpoleAggressive=Tools.parseBoolean(b);
+				tadpoleAggressive=Parse.parseBoolean(b);
 				if(tadpoleAggressive){tadpoleConservative=false;}
 			}else if(a.equals("tadpoleconservative") || a.equals("conservative") || a.equals("cecc")){
-				tadpoleConservative=Tools.parseBoolean(b);
+				tadpoleConservative=Parse.parseBoolean(b);
 				if(tadpoleConservative){tadpoleAggressive=false;}
 			}else if(a.equals("kt") || a.equals("ktadpole") || a.equals("tadpolek")){
 				tadpoleK=Integer.parseInt(b);
@@ -155,17 +156,17 @@ public class DecontaminateByNormalization {
 			
 			//Deprecated
 //			else if(a.equals("ecc")){
-//				ecc=Tools.parseBoolean(b);
+//				ecc=Parse.parseBoolean(b);
 //			}else if(a.equals("cecc")){
-//				cecc=Tools.parseBoolean(b);
+//				cecc=Parse.parseBoolean(b);
 //				if(cecc){ecc=true;aecc=false;}
 //			}else if(a.equals("aecc")){
-//				aecc=Tools.parseBoolean(b);
+//				aecc=Parse.parseBoolean(b);
 //				if(aecc){ecc=true;cecc=false;}
 //			}
 			
 			else if(a.equals("prefilter")){
-				prefilter=Tools.parseBoolean(b);
+				prefilter=Parse.parseBoolean(b);
 			}else if(a.equals("filterbits") || a.equals("fbits")){
 				filterBits=Integer.parseInt(b);
 			}else if(a.equals("prefilterbits") || a.equals("prebits") || a.equals("pbits")){
