@@ -2,6 +2,7 @@ package jgi;
 
 import java.util.ArrayList;
 
+import shared.Parse;
 import shared.Shared;
 import shared.Timer;
 import shared.Tools;
@@ -29,6 +30,11 @@ public final class FuseSequence extends BBTool_ST {
 	public FuseSequence(String[] args){
 		super(args);
 		reparse(args);
+		if(PAD_SYMBOL==0){PAD_SYMBOL='N';}
+		if(amino){
+			Shared.AMINO_IN=true;
+			if(PAD_SYMBOL=='N'){PAD_SYMBOL='X';}
+		}
 	}
 	
 	@Override
@@ -36,6 +42,8 @@ public final class FuseSequence extends BBTool_ST {
 		npad=300;
 		defaultQuality=30;
 		fusePairs=false;
+		PAD_SYMBOL=0;
+		amino=false;
 	}
 	
 	@Override
@@ -47,14 +55,20 @@ public final class FuseSequence extends BBTool_ST {
 			defaultQuality=Byte.parseByte(b);
 			return true;
 		}else if(a.equals("fp") || a.equals("fusepairs")){
-			fusePairs=Tools.parseBoolean(b);
+			fusePairs=Parse.parseBoolean(b);
 			return true;
 		}else if(a.equals("maxlen")){
-			maxlen=(int)Tools.min(Tools.parseKMG(b), Shared.MAX_ARRAY_LEN);
+			maxlen=(int)Tools.min(Parse.parseKMG(b), Shared.MAX_ARRAY_LEN);
 			return true;
 		}else if(a.equals("rename") || a.equals("name") || a.equals("prefix")){
 			name=(b==null ? "" : b);
 			return true;
+		}else if(a.equals("padsymbol")){
+			PAD_SYMBOL=b.charAt(0);
+			return true;
+		}else if(a.equals("amino")){
+			amino=Parse.parseBoolean(b);
+			return true;
 		}
 		return false;
 	}
@@ -168,7 +182,7 @@ public final class FuseSequence extends BBTool_ST {
 			if(quals!=null){quals[i]=r1.quality[i];}
 		}
 		for(int i=0, j=r1.length(); i<npad; i++, j++){
-			bases[j]='N';
+			bases[j]=(byte)PAD_SYMBOL;
 		}
 		for(int i=0, j=r1.length()+npad, max=r2.length(); i<max; i++, j++){
 			bases[j]=r2.bases[i];
@@ -184,7 +198,7 @@ public final class FuseSequence extends BBTool_ST {
 		if(name==null){name=r.id;}
 		if(bases.length>0){
 			for(int i=0; i<npad; i++){
-				bases.append('N');
+				bases.append(PAD_SYMBOL);
 				quals.append((byte)0);
 			}
 		}
@@ -217,5 +231,7 @@ public final class FuseSequence extends BBTool_ST {
 	ByteBuilder bases=new ByteBuilder();
 	ByteBuilder quals=new ByteBuilder();
 	String name;
+	char PAD_SYMBOL='N';
+	boolean amino=false;
 	
 }
