@@ -10,7 +10,7 @@ import java.util.Locale;
 import java.util.concurrent.atomic.AtomicLong;
 
 import bloom.KCountArray;
-import bloom.KmerCount7MTA;
+import bloom.ReadCounter;
 import bloom.KmerCountAbstract;
 import dna.AminoAcid;
 import fileIO.FileFormat;
@@ -70,7 +70,7 @@ public class KmerCoverage {
 		
 		int k=31;
 		int cbits=16;
-		int gap=0;
+//		int gap=0;
 		int hashes=4;
 		long cells=-1;
 		long maxReads=-1;
@@ -116,8 +116,6 @@ public class KmerCoverage {
 				cbits=Integer.parseInt(b);
 			}else if(a.startsWith("histlen") ||a.startsWith("histogramlen")){
 				HIST_LEN_PRINT=Tools.min(Integer.MAX_VALUE, Long.parseLong(b)+1);
-			}else if(a.startsWith("gap")){
-				gap=Integer.parseInt(b);
 			}else if(a.startsWith("matrixbits")){
 				int matrixbits=Integer.parseInt(b);
 				assert(matrixbits<63);
@@ -255,8 +253,6 @@ public class KmerCoverage {
 		}else{
 			THREADS=threads;
 		}
-//		KmerCountAbstract.THREADS=Tools.min(THREADS,6);
-		KmerCountAbstract.THREADS=THREADS;
 		
 //		System.err.println("THREADS="+THREADS+", KmerCountAbstract.THREADS="+KmerCountAbstract.THREADS);
 		
@@ -331,13 +327,14 @@ public class KmerCoverage {
 		KCountArray kca;
 		KCountArray prefilterArray=null;
 		outstream.println();
+		ReadCounter rc=new ReadCounter(k, true, false, false, Shared.AMINO_IN);
 		if(prefilter){
-			prefilterArray=KmerCount7MTA.makeKca(in1, in2, extra, k, 2, gap, precells, prehashes, minq, true, false, false,
-					tablereads, 1, buildStepsize, 1, 1, null, 0, Shared.AMINO_IN);
+			prefilterArray=rc.makeKca(in1, in2, extra, 2, precells, prehashes, minq,
+					tablereads, 1, buildStepsize, 1, 1, null, 0);
 			outstream.println("Made prefilter:   \t"+prefilterArray.toShortString(prehashes));
 		}
-		kca=KmerCount7MTA.makeKca(in1, in2, extra, k, cbits, gap, cells, hashes, minq, true, false, false,
-				tablereads, buildpasses, buildStepsize, 2, 2, prefilterArray, (prefilterArray==null ? 0 : prefilterArray.maxValue), Shared.AMINO_IN);
+		kca=rc.makeKca(in1, in2, extra, cbits, cells, hashes, minq,
+				tablereads, buildpasses, buildStepsize, 2, 2, prefilterArray, (prefilterArray==null ? 0 : prefilterArray.maxValue));
 		ht.stop();
 		
 		outstream.println("Made hash table:  \t"+kca.toShortString(hashes));
@@ -801,14 +798,12 @@ public class KmerCoverage {
 	
 	public static int[] generateCoverage(Read r, KCountArray kca, int k) {
 		if(k>31){return generateCoverageLong(r, kca, k);}
-		if(kca.gap>0){throw new RuntimeException();}
 		if(r==null || r.bases==null || r.length()<k){return new int[] {0};}
 		
 		final int kbits=2*k;
 		final long mask=(kbits>63 ? -1L : ~((-1L)<<kbits));
-		final int gap=kca.gap;
 		
-		if(r.bases==null || r.length()<k+gap){return null;} //Read is too short to detect errors
+		if(r.bases==null || r.length()<k){return null;} //Read is too short to detect errors
 		
 		int len=0;
 		long kmer=0;
@@ -867,14 +862,9 @@ public class KmerCoverage {
 	}
 	
 	public static int[] generateCoverageLong(Read r, KCountArray kca, int k) {
-//		assert(false) : "todo";
-//		assert(k>31);
-		if(kca.gap>0){throw new RuntimeException();}
 		if(r==null || r.bases==null || r.length()<k){return new int[] {0};}
 		
-		final int gap=kca.gap;
-		
-		if(r.bases==null || r.length()<k+gap){return null;} //Read is too short to detect errors
+		if(r.bases==null || r.length()<k){return null;} //Read is too short to detect errors
 		
 		int len=0;
 		long kmer=0;
