@@ -7,6 +7,7 @@ import java.util.ArrayList;
 import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -81,11 +82,11 @@ public class PartitionReads {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("ways")){
 				ways=Integer.parseInt(b);
 			}else if(a.equalsIgnoreCase("pacbio") || a.equals("subreads")){
-				pacBioMode=Tools.parseBoolean(b);
+				pacBioMode=Parse.parseBoolean(b);
 			}else if(a.equals("parse_flag_goes_here")){
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
@@ -322,7 +323,7 @@ public class PartitionReads {
 					basesProcessed+=initialLength1+initialLength2;
 					
 					if(pacBioMode){
-						int zmw=Tools.parseZmw(r1.id);
+						int zmw=Parse.parseZmw(r1.id);
 						assert(zmw>=0) : "Invalid zmw in "+r1.id;
 						nextIndex=(zmw%ways);
 					}
