@@ -11,7 +11,7 @@ import java.util.concurrent.atomic.AtomicLong;
 import java.util.concurrent.atomic.AtomicLongArray;
 
 import bloom.KCountArray;
-import bloom.KmerCount7MTA;
+import bloom.ReadCounter;
 import bloom.KmerCountAbstract;
 import dna.AminoAcid;
 import fileIO.FileFormat;
@@ -72,7 +72,6 @@ public class ReadKmerDepthDistribution {
 		
 		int k=31;
 		int cbits=32;
-		int gap=0;
 		int hashes=3;
 //		int matrixbits=-1;
 		long cells=-1;
@@ -123,8 +122,6 @@ public class ReadKmerDepthDistribution {
 				cbits=Integer.parseInt(b);
 			}else if(a.startsWith("histlen") ||a.startsWith("histogramlen")){
 				HIST_LEN_PRINT=Tools.min(Integer.MAX_VALUE, Long.parseLong(b)+1);
-			}else if(a.startsWith("gap")){
-				gap=Integer.parseInt(b);
 			}else if(a.startsWith("matrixbits")){
 				int matrixbits=Integer.parseInt(b);
 				assert(matrixbits<63);
@@ -265,8 +262,6 @@ public class ReadKmerDepthDistribution {
 		}else{
 			THREADS=threads;
 		}
-//		KmerCountAbstract.THREADS=Tools.min(THREADS,6);
-		KmerCountAbstract.THREADS=THREADS;
 		
 //		System.err.println("THREADS="+THREADS+", KmerCountAbstract.THREADS="+KmerCountAbstract.THREADS);
 		
@@ -347,9 +342,10 @@ public class ReadKmerDepthDistribution {
 		KCountArray kca;
 		KCountArray prefilterArray=null;
 //		outstream.println();
+		ReadCounter rc=new ReadCounter(k, true, false, false, Shared.AMINO_IN);
 		if(prefilter){
-			prefilterArray=KmerCount7MTA.makeKca(reads1, reads2, extra, k, 2, gap, precells, prehashes, minq, true, false, false,
-					tablereads, 1, buildStepsize, 1, 1, null, 0, Shared.AMINO_IN);
+			prefilterArray=rc.makeKca(reads1, reads2, extra, 2, precells, prehashes, minq,
+					tablereads, 1, buildStepsize, 1, 1, null, 0);
 			outstream.println("Made prefilter:   \t"+prefilterArray.toShortString(prehashes));
 			double uf=prefilterArray.usedFraction();
 			if(uf>0.6){
@@ -359,8 +355,8 @@ public class ReadKmerDepthDistribution {
 						"or increase the values of the minprob flag to reduce spurious kmers.");
 			}
 		}
-		kca=KmerCount7MTA.makeKca(reads1, reads2, extra, k, cbits, gap, cells, hashes, minq, true, false, false,
-				tablereads, buildpasses, buildStepsize, 2, 2, prefilterArray, (prefilterArray==null ? 0 : prefilterArray.maxValue), Shared.AMINO_IN);
+		kca=rc.makeKca(reads1, reads2, extra, cbits, cells, hashes, minq, 
+				tablereads, buildpasses, buildStepsize, 2, 2, prefilterArray, (prefilterArray==null ? 0 : prefilterArray.maxValue));
 		ht.stop();
 		
 		outstream.println("Made hash table:  \t"+kca.toShortString(hashes));
@@ -770,14 +766,12 @@ public class ReadKmerDepthDistribution {
 	
 	public static int[] generateCoverage(Read r, KCountArray kca, int k, int[] out, long[] kmers) {
 		if(k>31){return generateCoverageLong(r, kca, k, out);}
-		if(kca.gap>0){throw new RuntimeException("Gapped reads: TODO");}
 		if(r==null || r.bases==null || r.length()<k){return new int[] {0};}
 		
 		final int kbits=2*k;
 		final long mask=(kbits>63 ? -1L : ~((-1L)<<kbits));
-		final int gap=kca.gap;
 		
-		if(r.bases==null || r.length()<k+gap){return null;} //Read is too short to detect errors
+		if(r.bases==null || r.length()<k){return null;} //Read is too short to detect errors
 		
 		int len=0;
 		long kmer=0;
@@ -818,12 +812,9 @@ public class ReadKmerDepthDistribution {
 	
 	public static int[] generateCoverageLong(Read r, KCountArray kca, int k, int[] out) {
 		assert(k>31);
-		if(kca.gap>0){throw new RuntimeException();}
 		if(r==null || r.bases==null || r.length()<k){return new int[] {0};}
 		
-		final int gap=kca.gap;
-		
-		if(r.bases==null || r.length()<k+gap){return null;} //Read is too short to detect errors
+		if(r.bases==null || r.length()<k){return null;} //Read is too short to detect errors
 		
 		int len=0;
 		long kmer=0;
