@@ -8,6 +8,7 @@ import fileIO.ByteFile;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
 import shared.KillSwitch;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -73,19 +74,19 @@ public class Shred {
 			String b=split.length>1 ? split[1] : null;
 
 			if(a.equals("length") || a.equals("len") || a.equals("shredlen") || a.equals("shredlength")){
-				shredLength=Tools.parseIntKMG(b);
+				shredLength=Parse.parseIntKMG(b);
 			}else if(a.equals("overlap")){
-				overlap=Tools.parseIntKMG(b);
+				overlap=Parse.parseIntKMG(b);
 			}else if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("even") || a.equals("equal")){
-				even=Tools.parseBoolean(b);
+				even=Parse.parseBoolean(b);
 			}else if(a.equals("seed")){
 				seed=Long.parseLong(b);
 			}else if(a.equals("median")){
-				median=Tools.parseIntKMG(b);
+				median=Parse.parseIntKMG(b);
 			}else if(a.equals("variance")){
-				variance=Tools.parseIntKMG(b);
+				variance=Parse.parseIntKMG(b);
 			}else if(a.equals("parse_flag_goes_here")){
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){
@@ -149,10 +150,10 @@ public class Shred {
 	
 	public boolean parseArgument(String arg, String a, String b){
 		if(a.equals("reads") || a.equals("maxreads")){
-			maxReads=Tools.parseKMG(b);
+			maxReads=Parse.parseKMG(b);
 			return true;
 		}else if(a.equals("some_argument")){
-			maxReads=Tools.parseKMG(b);
+			maxReads=Parse.parseKMG(b);
 			return true;
 		}
 		return false;
