@@ -9,7 +9,7 @@ import java.util.Locale;
 import java.util.concurrent.atomic.AtomicLong;
 
 import bloom.KCountArray;
-import bloom.KmerCount7MTA;
+import bloom.ReadCounter;
 import bloom.KmerCountAbstract;
 import fileIO.ByteStreamWriter;
 import jgi.CallPeaks;
@@ -175,15 +175,16 @@ public abstract class AbstractKmerTableSet {
 		}
 		if(prehashes<1){prehashes=2;}
 
+		ReadCounter rc=new ReadCounter(kbig(), true, ecco(), false, Shared.AMINO_IN);
 		if(onePass){
 			assert(filter==null || filter.length==1) : "Multiple filtering passes are not allowed in onepass mode.\n"+filter.length+","+prepasses+", "+onePass+", "+prefilter;
-			filter[0]=KmerCount7MTA.makeKca(null, null, null, kbig(), cbits, 0, precells, prehashes, minq, true, ecco(), false,
-					maxReads, 1, 1, 1, 1, null, 0, Shared.AMINO_IN);
+			filter[0]=rc.makeKca(null, null, null, cbits, precells, prehashes, minq,
+					maxReads, 1, 1, 1, 1, null, 0);
 		}else{
 			if(ht==null){ht=new Timer();}
 			ht.start();
-			filter[0]=KmerCount7MTA.makeKca_als(in1, in2, extra, kbig(), cbits, 0, precells, prehashes, minq, true, ecco(), false,
-					maxReads, 1, 1, 1, 1, filter[0], filterMax, Shared.AMINO_IN);
+			filter[0]=rc.makeKca_als(in1, in2, extra, cbits, precells, prehashes, minq,
+					maxReads, 1, 1, 1, 1, filter[0], filterMax);
 			assert(filterMax<filter[0].maxValue || (currentPass>0 && currentPass==prepasses-1));
 			outstream.println("Made prefilter:   \t"+filter[0].toShortString(prehashes));
 			double uf=filter[0].usedFraction();
