@@ -272,7 +272,7 @@ public class KmerTableSet extends AbstractKmerTableSet {
 		if(ways_<1){
 			long maxKmers=(2*tableMemory)/bytesPerKmer;
 			long minWays=Tools.min(10000, maxKmers/Integer.MAX_VALUE);
-			ways_=(int)Tools.max(31, (int)(THREADS*2.5), minWays);
+			ways_=(int)Tools.max(31, (int)(Tools.min(96, Shared.threads())*2.5), minWays);
 			ways_=(int)Primes.primeAtLeast(ways_);
 			assert(ways_>0);
 //			System.err.println("ways="+ways_);
@@ -383,6 +383,8 @@ public class KmerTableSet extends AbstractKmerTableSet {
 		ScheduleMaker scheduleMaker=new ScheduleMaker(ways, bytesPerKmer, prealloc, 
 				(prealloc ? preallocFraction : 1.0), -1, (prefilter ? prepasses : 0), prefilterFraction, filterMemoryOverride);
 		int[] schedule=scheduleMaker.makeSchedule();
+		//assert(false) : preallocFraction+", "+ways+", "+Arrays.toString(schedule);
+//		System.err.println("DEBUG "+preallocFraction+", "+ways+", "+Arrays.toString(schedule));
 		tables=AbstractKmerTable.preallocate(ways, tableType, schedule, coreMask);
 		
 //		tables=AbstractKmerTable.preallocate(ways, tableType, initialSize, coreMask, (!prealloc || preallocFraction<1));
