@@ -134,8 +134,7 @@ public class MergeReadsAndGenome {
 			}
 		}
 		
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 	}
 	
 	public static long appendReads(ConcurrentReadInputStream cris, TextStreamWriter tsw, long id){
