@@ -321,7 +321,7 @@ public class RiboMaker implements Accumulator<RiboMaker.ProcessThread> {
 				long x=AminoAcid.baseToNumber[b];
 				long x2=AminoAcid.baseToComplementNumber[b];
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				
 				if(x>=0){
 					len++;
@@ -352,7 +352,7 @@ public class RiboMaker implements Accumulator<RiboMaker.ProcessThread> {
 			long x=AminoAcid.baseToNumber[b];
 			long x2=AminoAcid.baseToComplementNumber[b];
 			kmer=((kmer<<2)|x)&mask;
-			rkmer=(rkmer>>>2)|(x2<<shift2);
+			rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 
 			if(x>=0){
 				len++;
