@@ -321,7 +321,7 @@ public class ServerTools {
 	 * @param millis Time to wait
 	 */
 	public static void pause(long millis){
-		Integer lock=new Integer(1);
+		String lock=new String("1");
 		synchronized(lock){
 			final long time=System.currentTimeMillis()+millis;
 			while(System.currentTimeMillis()<time){
