@@ -7,6 +7,7 @@ import java.util.HashSet;
 
 import align2.QualityTools;
 import bloom.KCountArray;
+import bloom.KmerCountAbstract;
 import cardinality.CardinalityTracker;
 import cardinality.LogLog16;
 import cardinality.LogLog2;
@@ -439,7 +440,7 @@ public class Parser {
 	}
 	
 	public boolean parseMapping(String arg, String a, String b){
-		if(a.equals("idfilter") || a.equals("identityfilter") || a.equals("minidfilter") || a.equals("minidentityfilter") || a.equals("minid")){
+		if(a.equals("idfilter") || a.equals("identityfilter") || a.equals("minidfilter") || a.equals("minidentityfilter")){
 			minIdFilter=Float.parseFloat(b);
 			if(minIdFilter>1f){minIdFilter/=100;}
 			assert(minIdFilter<=1f) : "idfilter should be between 0 and 1.";
@@ -737,7 +738,8 @@ public class Parser {
 			TaxTree.protFull=true;
 		}
 		
-		else if(a.equalsIgnoreCase("lockedincrement")){
+		else if(a.equalsIgnoreCase("lockedincrement") || a.equalsIgnoreCase("symmetricwrite")
+				|| a.equalsIgnoreCase("symmetric") || a.equalsIgnoreCase("sw")){
 			if("auto".equalsIgnoreCase(b)){
 				KCountArray.LOCKED_INCREMENT=true;
 				KCountArray.SET_LOCKED_INCREMENT=false;
@@ -747,6 +749,19 @@ public class Parser {
 			}
 		}
 		
+		else if(a.equalsIgnoreCase("buffer") || a.equalsIgnoreCase("buffered")){
+			if(b!=null && Character.isDigit(b.charAt(0))){
+				int x=Parse.parseIntKMG(b);
+				KmerCountAbstract.BUFFERED=x>1;
+				if(x>1){KmerCountAbstract.BUFFERLEN=x;}
+			}else{
+				KmerCountAbstract.BUFFERED=Parse.parseBoolean(b);
+			}
+		}
+//		else if(a.equalsIgnoreCase("sortserial")){
+//			KmerCountAbstract.SORT_SERIAL=Parse.parseBoolean(b);
+//		}
+		
 		else{
 			return false;
 		}
