@@ -847,8 +847,7 @@ public class ReadStats {
 			tsw.print("\n");
 			if(y<=0){break;}
 		}
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 		errorState|=tsw.errorState;
 	}
 	
@@ -875,8 +874,7 @@ public class ReadStats {
 			tsw.print("\n");
 			if(y<=0){break;}
 		}
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 		errorState|=tsw.errorState;
 	}
 	
@@ -965,8 +963,7 @@ public class ReadStats {
 			}
 		}
 		tsw.print(sb);
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 		errorState|=tsw.errorState;
 	}
 	
@@ -1015,8 +1012,7 @@ public class ReadStats {
 			tsw.print("\n");
 			if(y<=0){break;}
 		}
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 		errorState|=tsw.errorState;
 	}
 	
@@ -1059,8 +1055,7 @@ public class ReadStats {
 			}
 			tsw.print("\n");
 		}
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 		errorState|=tsw.errorState;
 	}
 	
@@ -1139,8 +1134,7 @@ public class ReadStats {
 //			System.err.println(qm+"\t"+qs+"\t"+qi+"\t"+qd);
 		}
 		
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 		errorState|=tsw.errorState;
 	}
 	
@@ -1175,8 +1169,7 @@ public class ReadStats {
 					);
 			tsw.print("\n");
 		}
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 		errorState|=tsw.errorState;
 	}
 	
@@ -1201,8 +1194,7 @@ public class ReadStats {
 					);
 			tsw.print("\n");
 		}
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 		errorState|=tsw.errorState;
 	}
 	
@@ -1318,8 +1310,7 @@ public class ReadStats {
 				bsw.print(bb);
 			}
 		}
-		bsw.poison();
-		bsw.waitForFinish();
+		bsw.poisonAndWait();
 		errorState|=bsw.errorState;
 	}
 	
@@ -1361,8 +1352,7 @@ public class ReadStats {
 				bsw.print(bb);
 			}
 		}
-		bsw.poison();
-		bsw.waitForFinish();
+		bsw.poisonAndWait();
 		errorState|=bsw.errorState;
 	}
 	
@@ -1438,8 +1428,7 @@ public class ReadStats {
 				}
 			}
 		}
-		bsw.poison();
-		bsw.waitForFinish();
+		bsw.poisonAndWait();
 		errorState|=bsw.errorState;
 	}
 	
@@ -1478,8 +1467,7 @@ public class ReadStats {
 				bsw.print(bb);
 			}
 		}
-		bsw.poison();
-		bsw.waitForFinish();
+		bsw.poisonAndWait();
 		errorState|=bsw.errorState;
 	}
 	
@@ -1515,8 +1503,7 @@ public class ReadStats {
 				tsw.print(String.format(Locale.ROOT, "%.1f", i*mult)+"\t"+x+"\t"+x2+"\n");
 			}
 		}
-		tsw.poison();
-		tsw.waitForFinish();
+		tsw.poisonAndWait();
 		errorState|=tsw.errorState;
 	}
 	
