@@ -125,8 +125,8 @@ public class Shared {
 	public static final int GAPCOST=Tools.max(1, GAPLEN/64);
 	public static final byte GAPC='-';
 	
-	public static String BBMAP_VERSION_STRING="38.98";
-	public static String BBMAP_VERSION_NAME="Mistletoe";
+	public static String BBMAP_VERSION_STRING="39.01";
+	public static String BBMAP_VERSION_NAME="Smoked Paprika";
 	
 	public static boolean TRIM_READ_COMMENTS=false;
 	public static boolean TRIM_RNAME=false; //For mapped sam reads
@@ -629,7 +629,7 @@ public class Shared {
 	public static final long MAX_ARRAY_LEN=Integer.MAX_VALUE-20;
 	
 	public static final int parallelSortLength=10000;
-	public static boolean disableParallelSort=false;
+	private static boolean disableParallelSort=false;
 	public static boolean parallelSort=testParallelSort();
 	
 	public static double javaVersion=parseJavaVersion();
