@@ -8,7 +8,7 @@ import java.util.Map.Entry;
 import java.util.concurrent.atomic.AtomicInteger;
 
 import bloom.KCountArray;
-import bloom.KmerCount7MTA;
+import bloom.ReadCounter;
 import bloom.KmerCountAbstract;
 import dna.AminoAcid;
 import fileIO.ByteFile;
@@ -56,7 +56,7 @@ public class BlacklistMaker extends SketchObject {
 		//Start a timer immediately upon code entrance.
 		Timer t=new Timer();
 		
-		KmerCount7MTA.maxShortKmerLength=32;
+		ReadCounter.maxShortKmerLength=32;
 		
 		//Create an instance of this class
 		BlacklistMaker x=new BlacklistMaker(args);
@@ -64,7 +64,7 @@ public class BlacklistMaker extends SketchObject {
 		//Run the object
 		x.process(t);
 		
-		KmerCount7MTA.maxShortKmerLength=31;
+		ReadCounter.maxShortKmerLength=31;
 		
 		//Close the print stream if it was redirected
 		Shared.closeStream(x.outstream);
@@ -530,7 +530,8 @@ public class BlacklistMaker extends SketchObject {
 			Timer ht=new Timer();
 
 			ArrayList<String> extra=null;
-			filter[0]=KmerCount7MTA.makeKca(in1, in2, extra, k, cbits, 0, precells, prehashes, minq, rcomp, false, false, maxReads, 1, 1, 1, 1, filter[0], filterMax, amino);
+			ReadCounter rc=new ReadCounter(k, rcomp, false, false, amino);
+			filter[0]=rc.makeKca(in1, in2, extra, cbits, precells, prehashes, minq, maxReads, 1, 1, 1, 1, filter[0], filterMax);
 			assert(filterMax<=filter[0].maxValue || (currentPass==0)) : filterMax+", "+currentPass+", "+filter[0].maxValue;
 			outstream.println("Made prefilter:   \t"+filter[0].toShortString(prehashes));
 			double uf=filter[0].usedFraction();
