@@ -7,7 +7,7 @@ import java.util.HashMap;
 import java.util.Map.Entry;
 import java.util.concurrent.atomic.AtomicInteger;
 
-import bloom.KmerCount7MTA;
+import bloom.ReadCounter;
 import bloom.KmerCountAbstract;
 import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
@@ -48,7 +48,7 @@ public class BlacklistMaker2 extends SketchObject {
 		//Start a timer immediately upon code entrance.
 		Timer t=new Timer();
 		
-		KmerCount7MTA.maxShortKmerLength=32;
+		ReadCounter.maxShortKmerLength=32;
 		
 		//Create an instance of this class
 		BlacklistMaker2 x=new BlacklistMaker2(args);
@@ -56,7 +56,7 @@ public class BlacklistMaker2 extends SketchObject {
 		//Run the object
 		x.process(t);
 		
-		KmerCount7MTA.maxShortKmerLength=31;
+		ReadCounter.maxShortKmerLength=31;
 		
 		//Close the print stream if it was redirected
 		Shared.closeStream(x.outstream);
