@@ -631,6 +631,37 @@ public final class Comparison extends SketchObject implements Comparable<Compari
 		
 	}
 	
+	static class SSUComparator implements Comparator<Comparison>{
+
+		@Override
+		public int compare(Comparison a, Comparison b) {
+//			if((a.has16S() || a.has18S()) && !a.hasSSUIdentity()){
+//				synchronized(a){a.ssuIdentity();}
+//				assert(a.hasSSUIdentity());
+//			}
+//			if((b.has16S() || b.has18S()) && !b.hasSSUIdentity()){
+//				synchronized(b){b.ssuIdentity();}
+//				assert(b.hasSSUIdentity());
+//			}
+			
+			if(a.hasSSUIdentity() && b.hasSSUIdentity()){
+				final float sa=a.ssuIdentity(), sb=b.ssuIdentity();
+				return sa>sb ? 1 : sa<sb ? -1 : scoreComparator.compare(a, b);
+			}else if(a.hasSSUIdentity()){
+				return 1;
+			}else if(b.hasSSUIdentity()){
+				return -1;
+			}else{
+				return scoreComparator.compare(a, b);
+			}
+			
+		}
+		
+		@Override
+		public String toString(){return "sortBySSU";}
+		
+	}
+	
 	static class HitsComparator implements Comparator<Comparison>{
 
 		@Override
@@ -661,6 +692,7 @@ public final class Comparison extends SketchObject implements Comparable<Compari
 	public static final Depth2Comparator depth2Comparator=new Depth2Comparator();
 	public static final VolumeComparator volumeComparator=new VolumeComparator();
 	public static final KIDComparator KIDComparator=new KIDComparator();
+	public static final SSUComparator SSUComparator=new SSUComparator();
 	public static final WKIDComparator WKIDComparator=new WKIDComparator();
 	public static final HitsComparator HitsComparator=new HitsComparator();
 	private static final boolean sqrt=false;
