@@ -486,7 +486,7 @@ public class KmerLimit extends SketchObject {
 					long x2=AminoAcid.baseToComplementNumber[b];
 					
 					kmer=((kmer<<2)|x)&mask;
-					rkmer=(rkmer>>>2)|(x2<<shift2);
+					rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 					
 					if(x<0){len=0; rkmer=0;}else{len++;}
 					if(len>=k){
@@ -503,7 +503,7 @@ public class KmerLimit extends SketchObject {
 					final long x2=AminoAcid.baseToComplementNumber[b];
 					
 					kmer=((kmer<<2)|x)&mask;
-					rkmer=(rkmer>>>2)|(x2<<shift2);
+					rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 					
 					{//Quality-related stuff
 						final byte q=quals[i];
