@@ -805,7 +805,7 @@ public class KmerLimit2 extends SketchObject {
 					long x2=AminoAcid.baseToComplementNumber[b];
 					
 					kmer=((kmer<<2)|x)&mask;
-					rkmer=(rkmer>>>2)|(x2<<shift2);
+					rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 					
 					if(x<0){len=0; rkmer=0;}else{len++;}
 					if(len>=k){
@@ -839,7 +839,7 @@ public class KmerLimit2 extends SketchObject {
 					}
 					
 					kmer=((kmer<<2)|x)&mask;
-					rkmer=(rkmer>>>2)|(x2<<shift2);
+					rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 					
 					if(len>=k && prob>=minProb){
 						localHeap.genomeSizeKmers++;
