@@ -9,6 +9,7 @@ import fileIO.ByteFile;
 import fileIO.ByteStreamWriter;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.ReadStats;
@@ -88,7 +89,7 @@ public class MergeSketch extends SketchObject {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("verbose")){
-				verbose=Tools.parseBoolean(b);
+				verbose=Parse.parseBoolean(b);
 			}else if(a.equals("in")){
 				addFiles(b, in);
 			}else if(parseSketchFlags(arg, a, b)){
@@ -97,11 +98,11 @@ public class MergeSketch extends SketchObject {
 				//Do nothing
 			}
 //			else if(a.equals("size")){
-//				size=Tools.parseIntKMG(b);
+//				size=Parse.parseIntKMG(b);
 //			}
 			
 			else if(a.equals("parse_flag_goes_here")){
-				long fake_variable=Tools.parseKMG(b);
+				long fake_variable=Parse.parseKMG(b);
 				//Set a variable here
 			}
 			
