@@ -306,8 +306,9 @@ public class SendSketch extends SketchObject {
 		else if(refNames!=null){processRefMode(t);}
 		else{processRemote(t);}
 	}
-	
-	private void processRemote(Timer t){
+
+	@Deprecated
+	private void processRemote_old(Timer t){
 		Timer ttotal=new Timer();
 		
 		t.start();
@@ -403,6 +404,152 @@ public class SendSketch extends SketchObject {
 		if(!silent){tsw.println();}
 		tsw.poison();
 		
+//		outstream.println("sending "+bb.toString());
+		
+		if(outSketch!=null){
+			ByteStreamWriter bsw=new ByteStreamWriter(outSketch, overwrite, append, true, FileFormat.SKETCH);
+			bsw.start();
+			for(Sketch sk : inSketches){
+				sk.toBytes(bb);
+				bsw.print(bb);
+				bb.clear();
+			}
+			bsw.poisonAndWait();
+			errorState|=bsw.errorState;
+		}
+		
+		tsw.waitForFinish();
+		errorState|=tsw.errorState;
+		
+		t.stop();
+//		outstream.println("\nRan "+(inSketches.size()*refSketches.size())+" comparisons in \t"+t);
+		ttotal.stop();
+		if(!silent){outstream.println("Total Time: \t"+ttotal);}
+	}
+	
+
+	private void processRemote(Timer t){
+		Timer ttotal=new Timer();
+		
+		t.start();
+		inSketches=tool.loadSketches_MT(defaultParams, in);
+		final int numLoaded=(inSketches.size());
+		if(numLoaded>1 && defaultParams.mode==PER_FILE){
+			inSketches.sort(SketchIdComparator.comparator);//Otherwise they come out disordered
+		}
+		
+		t.stop();
+		if(!silent){outstream.println("Loaded "+numLoaded+" sketch"+(numLoaded==1 ? "" : "es")+" in "+t);}
+		assert(numLoaded<=MAX_ALLOWED_SKETCHES) : "\nSendSketch is configured to send at most "+MAX_ALLOWED_SKETCHES+" to prevent overwhelming the server.\n"
+				+ "If you need to compare more than that, please use CompareSketch locally instead.\n"
+				+ "References can be downloaded at http://portal.nersc.gov/dna/microbial/assembly/bushnell/\n";
+		t.start();
+//		outstream.println(inSketches.get(0));
+		
+		if(numLoaded>4000){
+			SEND_BUFFER_MAX_BYTES*=4;
+			SEND_BUFFER_MAX_SKETCHES*=4;
+		}else if(numLoaded>1000){
+			SEND_BUFFER_MAX_BYTES*=2;
+			SEND_BUFFER_MAX_SKETCHES*=2;
+		}
+//		SEND_BUFFER_MAX_SKETCHES=1;//This is for testing json array format.
+		
+		if(ffout==null){return;}
+		TextStreamWriter tsw=new TextStreamWriter(ffout);
+		tsw.start();
+		if(defaultParams.format==DisplayParams.FORMAT_QUERY_REF_ANI || defaultParams.format==DisplayParams.FORMAT_CONSTELLATION){tsw.println(defaultParams.header());}
+		
+		ByteBuilder bb=new ByteBuilder();
+		
+		int cntr=0;
+		int chunks=0;
+		boolean firstBlock=true; //Set to false after printing has started
+		final Sketch lastSketch=Tools.getLast(inSketches); //Last input sketch to process
+		for(Sketch sk : inSketches){
+			
+			if(sk.taxID<1 || sk.taxID>=minFakeID || outTaxID>0){sk.taxID=outTaxID;}
+			if(defaultParams.printSSU()){sk.loadSSU();}
+			
+			if(outSpid>0){sk.spid=outSpid;}
+			if(outImgID>0){sk.imgID=outImgID;}
+			if(outTaxName!=null){sk.setTaxName(outTaxName);}
+			if(outFname!=null){sk.setFname(outFname);}
+			if(outName0!=null){sk.setName0(outName0);}
+			sk.setMeta(outMeta);
+			
+			if(bb.length==0){
+				bb.append(defaultParams.toString(chunks));
+				chunks++;
+			}
+			sk.toBytes(bb);
+			cntr++;
+			if(cntr>=SEND_BUFFER_MAX_SKETCHES || bb.length>SEND_BUFFER_MAX_BYTES || sk==lastSketch){ //Don't allow too much data in a single transaction
+				if(verbose){outstream.println("Sending:\n"+bb);}
+//				outstream.println(cntr+", "+bb.length);
+				
+				byte[] message=bb.toBytes();
+				bb.clear();
+				try {
+//					outstream.println("Sending to "+address+"\n"+message+"\n"); //123
+					StringNum result=ServerTools.sendAndReceive(message, address);
+					if(!ServerTools.suppressErrors && (result.n<200 || result.n>299)){
+						System.err.println("ERROR: Server returned code "+result.n+" and this message:\n"+result.s);
+						KillSwitch.kill();
+					}
+					errorState|=checkForError(result.s);
+					if(!defaultParams.json()){
+						tsw.print(result.s);
+					}else{
+						String s=result.s;
+						
+						{//Fixes rare case of multiple sketches broken into single sketches per block
+							if(!firstBlock || sk!=lastSketch){
+								if(s.charAt(0)!='['){s="["+s;}
+								if(!s.endsWith("]")){;s=s+"]";}
+							}
+						}
+						
+						{//Case where there are more than one block of sketches, breaking JSON array format
+							if(!firstBlock){
+								s=","+s.substring(1);
+							}
+							if(sk!=lastSketch){
+								s=s.substring(0, s.length()-1);
+							}
+						}
+						
+						tsw.print(s);
+						firstBlock=false;
+					}
+				} catch (Exception e) {
+					// TODO Auto-generated catch block
+					e.printStackTrace();
+				}
+				cntr=0;
+			}
+		}
+		
+		if(bb.length>0){//This should no longer trigger unless there are no sketches since it's handled above.
+			if(verbose){outstream.println("Sending:\n"+bb);}
+			byte[] message=bb.toBytes();
+			bb.clear();
+			try {
+				StringNum result=ServerTools.sendAndReceive(message, address);
+				if(!ServerTools.suppressErrors && (result.n<200 || result.n>299)){
+					System.err.println("ERROR: Server returned code "+result.n+" and this message:\n"+result.s);
+					KillSwitch.kill();
+				}
+				errorState|=checkForError(result.s);
+				tsw.print(result.s);
+			} catch (Exception e) {
+				// TODO Auto-generated catch block
+				e.printStackTrace();
+			}
+		}
+		if(!silent){tsw.println();}
+		tsw.poison();
+		
 //		outstream.println("sending "+bb.toString());
 		
 		if(outSketch!=null){
