@@ -1132,7 +1132,7 @@ public class SketchMaker extends SketchObject {
 			final Long key;
 			if(imgID>-1 && (mode==PER_IMG || taxID<1)){key=imgID;}
 			else if(taxID>-1){key=(long)taxID;}
-			else{key=new Long(nextUnknown.getAndIncrement());}
+			else{key=Long.valueOf(nextUnknown.getAndIncrement());}
 			
 			//assert(!localMap.containsKey((long)taxID) || localMap.get((long)taxID)==smm.heap) : taxID; //123
 
