@@ -313,7 +313,7 @@ public class SketchMakerMini extends SketchObject {
 				long x2=AminoAcid.baseToComplementNumber[b];
 				
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				if(eTracker!=null){eTracker.add(b);}
 				if(x<0){
 					len=0;
@@ -365,7 +365,7 @@ public class SketchMakerMini extends SketchObject {
 				final long x2=AminoAcid.baseToComplementNumber[b];
 
 				kmer=((kmer<<2)|x)&mask;
-				rkmer=(rkmer>>>2)|(x2<<shift2);
+				rkmer=((rkmer>>>2)|(x2<<shift2))&mask;
 				if(eTracker!=null){eTracker.add(b);}
 
 				final byte q=quals[i];
