@@ -549,7 +549,7 @@ public class SketchObject {
 	 * @return Hash code
 	 */
 	private static final long hashToValue2(final long kmer0, final long rkmer0){
-//		return Tools.max(hash64shift(kmer0), hash64shift(kmer0&0xFFFFFFFFFFFFL));//Something like this would be around 10% faster; not worth it.
+//		return Tools.max(Tools.hash64shift(kmer0), Tools.hash64shift(kmer0&0xFFFFFFFFFFFFL));//Something like this would be around 10% faster; not worth it.
 		long kmer=kmer0, rkmer=rkmer0;
 		final long key;
 		final boolean useK1;
@@ -605,22 +605,6 @@ public class SketchObject {
 		return hashcode;
 	}
 	
-	/** Taken from Thomas Wang, Jan 1997:
-	 * http://web.archive.org/web/20071223173210/http://www.concentric.net/~Ttwang/tech/inthash.htm
-	 * 
-	 *  This is much faster than the table version.  Results seem similar y.
-	 */
-	private static long hash64shift(long key){
-		key = (~key) + (key << 21); // key = (key << 21) - key - 1;
-		key = key ^ (key >>> 24);
-		key = (key + (key << 3)) + (key << 8); // key * 265
-		key = key ^ (key >>> 14);
-		key = (key + (key << 2)) + (key << 4); // key * 21
-		key = key ^ (key >>> 28);
-		key = key + (key << 31);
-		return key;
-	}
-	
 	/**
 	 * Fastest version!
 	 * Generates a hash code from a kmer.
@@ -646,7 +630,7 @@ public class SketchObject {
 	 * @return Hash code
 	 */
 	private static final long hash2(final long kmer0){
-//		return hash64shift(kmer0);
+//		return Tools.hash64shift(kmer0);
 		long kmer=kmer0;
 		long code=0;
 		
@@ -672,7 +656,7 @@ public class SketchObject {
 	 * @return Hash code
 	 */
 	private static final long hash3(final long kmer0){
-//		return hash64shift(kmer0);
+//		return Tools.hash64shift(kmer0);
 		
 		long kmer=kmer0;
 		long code=0;
