@@ -9,6 +9,7 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLong;
 
+import shared.Parse;
 import shared.Shared;
 import shared.Tools;
 import structures.AbstractBitSet;
@@ -33,7 +34,7 @@ public class SketchSearcher extends SketchObject {
 		}else if(defaultParams.parse(arg, a, b)){
 			//Do nothing
 		}else if(a.equals("verbose")){
-			verbose=Tools.parseBoolean(b);
+			verbose=Parse.parseBoolean(b);
 		}else if(a.equals("ref")){
 			addRefFiles(b);
 		}else if(arg.equalsIgnoreCase("nt") || arg.equalsIgnoreCase("RefSeq") || arg.equalsIgnoreCase("refseqbig") || arg.equalsIgnoreCase("nr")
@@ -54,7 +55,7 @@ public class SketchSearcher extends SketchObject {
 				makeIndex=true;
 			}else{
 				autoIndex=false;
-				makeIndex=Tools.parseBoolean(b);
+				makeIndex=Parse.parseBoolean(b);
 			}
 		}else if(a.equals("indexsize") || a.equals("indexlimit")){
 			SketchIndex.indexLimit=Integer.parseInt(b);
@@ -409,7 +410,7 @@ public class SketchSearcher extends SketchObject {
 			if(!setK){k=defaultK; k2=defaultK2;}
 			if(!SET_AUTOSIZE_FACTOR){AUTOSIZE_FACTOR=4.5f;}
 		}else if(a.equalsIgnoreCase("silva")){
-//			TaxTree.SILVA_MODE=Tools.parseBoolean(b);
+//			TaxTree.SILVA_MODE=Parse.parseBoolean(b);
 			addRefFiles(SILVA_PATH());
 			if(blacklist==null){blacklist=Blacklist.silvaBlacklist();}
 			if(defaultParams.dbName==null){defaultParams.dbName="Silva";}
