@@ -9,6 +9,7 @@ import java.util.Locale;
 import fileIO.TextFile;
 import fileIO.TextStreamWriter;
 import shared.Colors;
+import shared.Parse;
 import shared.Parser;
 import shared.PreParser;
 import shared.Shared;
@@ -59,15 +60,15 @@ public class SummarizeSketchStats {
 			String b=split.length>1 ? split[1] : null;
 			
 			if(a.equals("printtotal") || a.equals("pt")){
-				printTotal=Tools.parseBoolean(b);
+				printTotal=Parse.parseBoolean(b);
 			}else if(a.equals("ignoresametaxa")){
-				ignoreSameTaxa=Tools.parseBoolean(b);
+				ignoreSameTaxa=Parse.parseBoolean(b);
 			}else if(a.equals("ignoresamebarcode") || a.equals("ignoresameindex")){
-				ignoreSameBarcode=Tools.parseBoolean(b);
+				ignoreSameBarcode=Parse.parseBoolean(b);
 			}else if(a.equals("ignoresamelocation") || a.equals("ignoresameloc")){
-				ignoreSameLocation=Tools.parseBoolean(b);
+				ignoreSameLocation=Parse.parseBoolean(b);
 			}else if(a.equals("usetotal") || a.equals("totaldenominator") || a.equals("totald") || a.equals("td")){
-				totalDenominator=Tools.parseBoolean(b);
+				totalDenominator=Parse.parseBoolean(b);
 			}
 			
 			else if(a.equals("taxtree") || a.equals("tree")){
@@ -78,9 +79,9 @@ public class SummarizeSketchStats {
 					taxLevel=TaxTree.levelToExtended(taxLevel);
 				}
 			}else if(a.equalsIgnoreCase("unique") || a.equalsIgnoreCase("uniquehits")){
-				uniqueHitsForSecond=Tools.parseBoolean(b);
+				uniqueHitsForSecond=Parse.parseBoolean(b);
 			}else if(a.equalsIgnoreCase("header") || a.equalsIgnoreCase("printheader")){
-				printHeader=Tools.parseBoolean(b);
+				printHeader=Parse.parseBoolean(b);
 			}
 			
 			else if(parser.parse(arg, a, b)){
