@@ -132,6 +132,10 @@ public class MergeSorted {
 				if(Parse.parseBoolean(b)){
 					comparator=ReadComparatorFlowcell.comparator;
 				}
+			}else if(a.equalsIgnoreCase("clump") || a.equalsIgnoreCase("clumpify")){
+				if(Parse.parseBoolean(b)){
+					comparator=ReadComparatorClump.comparator;
+				}
 			}else if(a.equals("table") || a.equals("gi") || a.equals("gitable")){
 				if(b==null || "ignore".equalsIgnoreCase(b) || "skip".equalsIgnoreCase(b)){
 					giTableFile=null;
@@ -161,6 +165,12 @@ public class MergeSorted {
 		if("auto".equalsIgnoreCase(giTableFile)){giTableFile=TaxTree.defaultTableFile();}
 		if("auto".equalsIgnoreCase(accessionFile)){accessionFile=TaxTree.defaultAccessionFile();}
 		
+		if(comparator==ReadComparatorTopological.comparator && genKmer){
+			comparator=ReadComparatorTopological5Bit.comparator;
+		}else{
+			genKmer=false;
+		}
+		
 		comparator.setAscending(ascending);
 		SamLine.SET_FROM_OK=true;
 		
@@ -250,15 +260,13 @@ public class MergeSorted {
 			}
 		}
 		
-		tempExt=".fq.gz";
-		if(extout==null){
-			if(ffout1!=null){
-				tempExt=ffout1.fasta() ? ".fa.gz" : ffout1.samOrBam() ? ".sam" : ".fq.gz";
+		{
+			FileFormat ffin=null;
+			if(in1!=null && in1.size()>0){
+				ffin=FileFormat.testInput(in1.get(0), null, false);
 			}
-		}else{
-			tempExt=extout;
+			tempExt=Tools.getTempExt(ffin, ffout1, extout);
 		}
-		
 	}
 	
 	/*--------------------------------------------------------------*/
@@ -373,6 +381,10 @@ public class MergeSorted {
 	
 	private boolean allowInputSubprocess=true;
 	
+	private String tempExt=null;
+	
+	private boolean genKmer=true;
+	
 	/*--------------------------------------------------------------*/
 	/*----------------         Final Fields         ----------------*/
 	/*--------------------------------------------------------------*/
@@ -382,8 +394,6 @@ public class MergeSorted {
 	/** Secondary output file */
 	private final FileFormat ffout2;
 	
-	private String tempExt=null;
-	
 	private static ReadComparator comparator=ReadComparatorName.comparator;
 	
 	/*--------------------------------------------------------------*/
