@@ -107,7 +107,9 @@ public class SortByName {
 			}else if(a.equals("allowtemp") || a.equals("usetemp")){
 				allowTempFiles=Parse.parseBoolean(b);
 			}else if(a.equals("memmult") || a.equals("mult")){
-				memMult=(float) Double.parseDouble(b);
+				memBlockMult=(float) Double.parseDouble(b);
+			}else if(a.equals("memlimit")){
+				memTotalMult=(float) Double.parseDouble(b);
 			}else if(a.equals("ascending")){
 				ascending=Parse.parseBoolean(b);
 			}else if(a.equals("descending")){
@@ -146,6 +148,10 @@ public class SortByName {
 				if(Parse.parseBoolean(b)){
 					comparator=ReadComparatorFlowcell.comparator;
 				}
+			}else if(a.equalsIgnoreCase("clump") || a.equalsIgnoreCase("clumpify")){
+				if(Parse.parseBoolean(b)){
+					comparator=ReadComparatorClump.comparator;
+				}
 			}else if(a.equals("table") || a.equals("gi") || a.equals("gitable")){
 				if(b==null || "ignore".equalsIgnoreCase(b) || "skip".equalsIgnoreCase(b)){
 					giTableFile=null;
@@ -159,6 +165,8 @@ public class SortByName {
 				maxFiles=Integer.parseInt(b);
 				assert(maxFiles>1 && maxFiles<=10000000) : "Invalid value for maxfiles: "+maxFiles+"; range is 2-10000000";
 				setMaxFiles=true;
+			}else if(a.equals("genkmer")){
+				genKmer=Parse.parseBoolean(b);
 			}else if(a.equals("parse_flag_goes_here")){
 				//Set a variable here
 			}else if(parser.parse(arg, a, b)){//Parse standard flags in the parser
@@ -173,6 +181,14 @@ public class SortByName {
 		if("auto".equalsIgnoreCase(giTableFile)){giTableFile=TaxTree.defaultTableFile();}
 		if("auto".equalsIgnoreCase(accessionFile)){accessionFile=TaxTree.defaultAccessionFile();}
 		
+		if(comparator==ReadComparatorTopological.comparator && genKmer){
+			comparator=ReadComparatorTopological5Bit.comparator;
+		}else{
+			genKmer=false;
+		}
+		
+		clump=(comparator==ReadComparatorClump.comparator);
+		
 		comparator.setAscending(ascending);
 		SamLine.SET_FROM_OK=true;
 		
@@ -274,14 +290,7 @@ public class SortByName {
 		ffout1=FileFormat.testOutput(out1, FileFormat.FASTQ, extout, true, overwrite, append, false);
 		ffout2=FileFormat.testOutput(out2, FileFormat.FASTQ, extout, true, overwrite, append, false);
 		
-		tempExt=".fq.gz";
-		if(extout==null){
-			if(ffout1!=null){
-				tempExt=ffout1.fasta() ? ".fa.gz" : ffout1.samOrBam() ? ".sam" : ".fq.gz";
-			}
-		}else{
-			tempExt=extout;
-		}
+		tempExt=Tools.getTempExt(ffin1, ffout1, extout);
 		
 		if(comparator==ReadComparatorPosition.comparator){
 			if(ReadComparatorPosition.scafMap==null){
@@ -373,8 +382,8 @@ public class SortByName {
 		ArrayList<Read> storage=new ArrayList<Read>();
 		
 		final long maxMem=Shared.memAvailable(1);
-		final long memLimit=(long)(maxMem*.75);
-		final long currentLimit=(long)(maxMem*memMult);
+		final long memLimit=(long)(maxMem*memTotalMult);//Crashed once at old 0.75 value
+		final long currentLimit=(long)(maxMem*memBlockMult);
 		final int readLimit=2000000000;
 		long currentMem=0;
 		long bytesDumped=0;
@@ -382,7 +391,8 @@ public class SortByName {
 //		IntList dumpCount=new IntList();
 		AtomicLong outstandingMem=new AtomicLong();
 		
-		if(verbose){outstream.println("maxMem="+maxMem+", memLimit="+memLimit+", currentLimit="+currentLimit+", currentLimit="+currentLimit);}
+		if(verbose){outstream.println("maxMem="+maxMem+", memLimit="+memLimit+
+				", currentMem="+currentMem+", currentLimit="+currentLimit);}
 		
 		{
 			//Grab the first ListNum of reads
@@ -415,6 +425,8 @@ public class SortByName {
 					maxLengthObserved=Tools.max(maxLengthObserved, initialLength1, initialLength2);
 					
 					if(minlen<1 || initialLength1>=minlen || initialLength2>=minlen){
+						if(genKmer){ReadComparatorTopological5Bit.genKmer(r1);}
+						else if(clump){ReadComparatorClump.set(r1);}
 						currentMem+=r1.countBytes()+(r2==null ? 0 : r2.countBytes());
 						storage.add(r1);
 					}
@@ -459,6 +471,10 @@ public class SortByName {
 				sortAndDump(storage, currentMem, outstandingMem, out1, useSharedHeader);
 				storage=null;
 				waitOnMemory(outstandingMem, 0);
+			}else{
+				Timer t=new Timer();
+				Shared.sort(storage, comparator);//For timing/testing.
+				t.stop("Sort Time: \t\t\t");
 			}
 		}else{
 //			dumpCount.add(storage.size());
@@ -471,7 +487,7 @@ public class SortByName {
 		}
 		
 	}
-	
+
 	private void waitOnMemory(AtomicLong outstandingMem, long target){
 		if(outstandingMem.get()>target){
 			if(verbose){outstream.println("Syncing; outstandingMem="+outstandingMem);}
@@ -651,9 +667,10 @@ public class SortByName {
 	
 	private static void mergeAndDump(final PriorityQueue<CrisContainer> q, final ConcurrentReadOutputStream ros, PrintStream outstream) {
 		
-		for(CrisContainer cc : q){
-			assert(!cc.cris().paired()) : FASTQ.TEST_INTERLEAVED+", "+FASTQ.FORCE_INTERLEAVED;
-		}
+//		for(CrisContainer cc : q){
+//			assert(!cc.cris().paired()) : FASTQ.TEST_INTERLEAVED+", "+FASTQ.FORCE_INTERLEAVED+
+//				", "+cc.cris().fname()+", "+cc.cris().getClass();
+//		}
 		
 		long maxLen=0;
 		
@@ -685,7 +702,7 @@ public class SortByName {
 				Read a=buffer.get(i-1);
 				Read b=buffer.get(i);
 				assert(comparator.compare(a, b)<=0) : "\n"+a+"\n"+b;
-				assert(a.mate==null) : "\n"+a+"\n"+b;
+//				assert(a.mate==null) : "\n"+a+"\n"+b;
 			}
 			
 			final Read peek=(q.isEmpty() ? null : q.peek().peek());
@@ -838,6 +855,8 @@ public class SortByName {
 			}else{ros=null;}
 
 			if(verbose){outstream.println("Started a ros.");}
+			
+			
 			Shared.sort(storage, comparator);
 			
 			if(verbose){outstream.println("Sorted reads.");}
@@ -928,8 +947,9 @@ public class SortByName {
 	private boolean allowTempFiles=true;
 	
 	private int minlen=0;
-	
-	private float memMult=0.35f;
+
+	private float memBlockMult=0.30f; //Crashed once at old default 0.35
+	private float memTotalMult=0.65f; //Crashed once at old default 0.75
 	
 	/** Max files to merge per pass */
 	private int maxFiles=12;
@@ -937,6 +957,8 @@ public class SortByName {
 	
 	private static int mergeFileLimit=24;
 	
+	private boolean genKmer=true;
+	
 	/*--------------------------------------------------------------*/
 	/*----------------         Final Fields         ----------------*/
 	/*--------------------------------------------------------------*/
@@ -951,6 +973,8 @@ public class SortByName {
 	/** Secondary output file */
 	private final FileFormat ffout2;
 	
+	private final boolean clump;
+	
 	private static ReadComparator comparator=ReadComparatorName.comparator;
 	
 	/*--------------------------------------------------------------*/
