@@ -21,7 +21,7 @@ public abstract class ConcurrentReadInputStream implements ConcurrentReadStreamI
 	/*----------------        Initialization        ----------------*/
 	/*--------------------------------------------------------------*/
 	
-	protected ConcurrentReadInputStream(){}
+	protected ConcurrentReadInputStream(String fname_){fname=fname_;}
 	
 	/**
 	 * Special method for testing, handles some parsing.
@@ -276,6 +276,9 @@ public abstract class ConcurrentReadInputStream implements ConcurrentReadStreamI
 
 	@Override
 	public abstract boolean paired();
+
+	@Override
+	public String fname(){return fname;}
 	
 	@Override
 	public abstract Object[] producers();
@@ -302,6 +305,7 @@ public abstract class ConcurrentReadInputStream implements ConcurrentReadStreamI
 	final int BUF_LEN=Shared.bufferLen();;
 	final int NUM_BUFFS=Shared.numBuffers();
 	final long MAX_DATA=Shared.bufferData();
+	public final String fname;
 	public boolean ALLOW_UNEQUAL_LENGTHS=false;
 	boolean started=false;
 	
