@@ -5,9 +5,9 @@ import java.util.ArrayList;
 import java.util.LinkedHashMap;
 import java.util.Map.Entry;
 
+import cardinality.CardinalityTracker;
 import fileIO.FileFormat;
 import fileIO.ReadWrite;
-import jgi.LogLog;
 import shared.KillSwitch;
 import shared.Shared;
 import structures.ByteBuilder;
@@ -211,7 +211,7 @@ public class MultiCros3 extends BufferedMultiCros {
 			ff2=FileFormat.testOutput(s2, defaultFormat, null, allowSubprocess, false, true, false);
 			
 			list=new ArrayList<Read>(readsPerBuffer);
-			if(trackCardinality){loglog=new LogLog();}
+			if(trackCardinality){loglog=CardinalityTracker.makeTracker();}
 			if(verbose){System.err.println("Made buffer for "+name);}
 		}
 		
@@ -394,7 +394,7 @@ public class MultiCros3 extends BufferedMultiCros {
 		/** Number of dumps executed */
 		private long numDumps=0;
 		/** Optional, for tracking cardinality */
-		private LogLog loglog;
+		private CardinalityTracker loglog;
 		
 	}
 	
