@@ -833,6 +833,19 @@ public class SamLine implements Serializable {
 		
 		return sb.toString();
 	}
+
+	public boolean cigarContainsOnlyME() {
+		if(cigar==null || cigar.length()==0){return false;}
+		for(int i=0; i<cigar.length(); i++){
+			char c=cigar.charAt(i);
+			if(Character.isDigit(c) || c=='M' || c=='='){
+				//do nothing;
+			}else{
+				return false;
+			}
+		}
+		return true;
+	}
 	
 	public int calcCigarLength(boolean includeSoftClip, boolean includeHardClip){
 		return calcCigarLength(cigar, includeSoftClip, includeHardClip);
