@@ -81,6 +81,8 @@ public class RenameGiToTaxid {
 				giTableFile=b;
 			}else if(a.equals("accession")){
 				accessionFile=b;
+			}else if(a.equals("pattern")){
+				patternFile=b;
 			}else if(a.equals("tree") || a.equals("taxtree")){
 				taxTreeFile=b;
 			}else if(a.equals("invalid")){
@@ -155,8 +157,9 @@ public class RenameGiToTaxid {
 		if(useServer){
 			giTableFile=null;
 			accessionFile=null;
+			patternFile=null;
 			if(mode!=UNITE_MODE){taxTreeFile=null;}
-		}
+		}//else if taxpath!=null... set them
 		
 		{//Process parser fields
 			Parser.processQuality();
@@ -172,6 +175,7 @@ public class RenameGiToTaxid {
 		if("auto".equalsIgnoreCase(taxTreeFile)){taxTreeFile=TaxTree.defaultTreeFile();}
 		if("auto".equalsIgnoreCase(giTableFile)){giTableFile=TaxTree.defaultTableFile();}
 		if("auto".equalsIgnoreCase(accessionFile)){accessionFile=TaxTree.defaultAccessionFile();}
+		if("auto".equalsIgnoreCase(patternFile)){patternFile=TaxTree.defaultPatternFile();}
 		
 		assert(FastaReadInputStream.settingsOK());
 		
@@ -215,6 +219,14 @@ public class RenameGiToTaxid {
 		if(giTableFile!=null){
 			GiToTaxid.initialize(giTableFile);
 		}
+		
+		if(patternFile!=null){
+			Timer t=new Timer();
+			AnalyzeAccession.loadCodeMap(patternFile);
+			outstream.println("Loading pattern table.");
+			t.stopAndPrint();
+		}
+		
 		if(accessionFile!=null){
 			AccessionToTaxid.tree=tree;
 			outstream.println("Loading accession table.");
@@ -823,6 +835,7 @@ public class RenameGiToTaxid {
 	private String taxTreeFile=null;
 	private String giTableFile=null;
 	private String accessionFile=null;
+	private String patternFile=null;
 	
 	/*--------------------------------------------------------------*/
 
