@@ -24,6 +24,29 @@ public class ThreadWaiter {
 		return success;
 	}
 	
+	public static final <T extends Thread> void startThreads(Iterable<T> iter){
+		for(Thread t : iter){t.start();}
+	}
+	
+	/**
+	 * @param iter List of Threads.
+	 * @return success
+	 */
+	public static final <T extends Thread> boolean startAndWait(Iterable<T> iter){
+		startThreads(iter);
+		return waitForThreads(iter);
+	}
+	
+	/**
+	 * @param iter List of Threads.
+	 * @return success
+	 */
+	public static final <T extends Thread> boolean startAndWait(Iterable<T> iter, Accumulator<T> acc){
+		startThreads(iter);
+//		assert(false);
+		return waitForThreads(iter, acc);
+	}
+	
 	/** Wait for completion of all threads, and accumulate results */
 	public static final <T extends Thread> boolean waitForThreads(Iterable<T> iter, Accumulator<T> acc){
 
