@@ -334,7 +334,7 @@ public abstract class AbstractKmerTableU {
 		}
 	}
 	
-	public static final ByteBuilder toBytes(long[] array, int count, int k, ByteBuilder sb){
+	public static final ByteBuilder toBytes(long[] array, long count, int k, ByteBuilder sb){
 		if(FASTA_DUMP){
 			sb.append('>');
 			sb.append(count);
