@@ -274,7 +274,7 @@ public class KmerTableSetU extends AbstractKmerTableSet {
 		if(ways_<1){
 			long maxKmers=(2*tableMemory)/bytesPerKmer;
 			long minWays=Tools.min(10000, maxKmers/Integer.MAX_VALUE);
-			ways_=(int)Tools.max(31, (int)(THREADS*2.5), minWays);
+			ways_=(int)Tools.max(31, (int)(Tools.min(96, Shared.threads())*2.5), minWays);
 			ways_=(int)Primes.primeAtLeast(ways_);
 			assert(ways_>0);
 //			System.err.println("ways="+ways_);
