@@ -406,7 +406,7 @@ public class CallVariants {
 			return null;
 		}
 		
-		KCountArray7MTA kca=new KCountArray7MTA(precells, cbits, 0, 2, null, minReads);
+		KCountArray7MTA kca=new KCountArray7MTA(precells, cbits, 2, null, minReads);
 		if(!useStreamer || !useStreamerMF || ffin.size()<2 || Shared.threads()<5 || (maxReads>=0 && maxReads<Long.MAX_VALUE)){
 			prefilter_SF(kca);
 		}else{
