@@ -690,7 +690,7 @@ public class CallVariants2 {
 				return null;
 			}
 
-			KCountArray7MTA kca=new KCountArray7MTA(precells, cbits, 0, 2, null, minReads);
+			KCountArray7MTA kca=new KCountArray7MTA(precells, cbits, 2, null, minReads);
 
 			if(ref==null){
 				ScafMap.loadSamHeader(ff, scafMap);
