@@ -5,6 +5,7 @@ import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 
+import shared.Parse;
 import shared.Tools;
 import structures.ByteBuilder;
 
@@ -40,7 +41,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		
 		while(b<line.length && line[b]!='\t'){b++;}
 		assert(b>a) : "Missing field 1: "+new String(line);
-		pos=Tools.parseInt(line, a, b);
+		pos=Parse.parseInt(line, a, b);
 		b++;
 		a=b;
 		
@@ -68,7 +69,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		
 		while(b<line.length && line[b]!='\t'){b++;}
 		assert(b>a) : "Missing field 5: "+new String(line);
-		qual=(line[a]=='.' && b==a+1 ? 40 : Tools.parseDouble(line, a, b));
+		qual=(line[a]=='.' && b==a+1 ? 40 : Parse.parseDouble(line, a, b));
 		b++;
 		a=b;
 		
@@ -127,7 +128,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 0: "+new String(info);
-		int scaf=Tools.parseInt(info, a, b);
+		int scaf=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 
@@ -135,7 +136,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 1: "+new String(info);
-		int start=Tools.parseInt(info, a, b);
+		int start=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 
@@ -143,7 +144,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 2: "+new String(info);
-		int stop=Tools.parseInt(info, a, b);
+		int stop=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 
@@ -168,7 +169,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 4: "+new String(info);
-		int r1p=Tools.parseInt(info, a, b);
+		int r1p=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 
@@ -176,7 +177,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 5: "+new String(info);
-		int r1m=Tools.parseInt(info, a, b);
+		int r1m=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 
@@ -184,7 +185,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 6: "+new String(info);
-		int r2p=Tools.parseInt(info, a, b);
+		int r2p=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 
@@ -192,7 +193,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 7: "+new String(info);
-		int r2m=Tools.parseInt(info, a, b);
+		int r2m=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 		
@@ -202,7 +203,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 8: "+new String(info);
-//		int ad=Tools.parseInt(info, a, b);
+//		int ad=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 
@@ -210,7 +211,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 9: "+new String(info);
-		int cov=Tools.parseInt(info, a, b);
+		int cov=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 
@@ -218,7 +219,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 10: "+new String(info);
-		int mcov=Tools.parseInt(info, a, b);
+		int mcov=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 		
@@ -227,7 +228,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 11: "+new String(info);
-		int pc=Tools.parseInt(info, a, b);
+		int pc=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 		
@@ -236,7 +237,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 12: "+new String(info);
-//		double af=Tools.parseDouble(info, a, b);
+//		double af=Parse.parseDouble(info, a, b);
 		b++;
 		a=b;
 		
@@ -245,7 +246,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 13: "+new String(info);
-		double raf=Tools.parseDouble(info, a, b);
+		double raf=Parse.parseDouble(info, a, b);
 		b++;
 		a=b;
 		
@@ -253,7 +254,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 14: "+new String(info);
-		long ls=Tools.parseLong(info, a, b);
+		long ls=Parse.parseLong(info, a, b);
 		b++;
 		a=b;
 		
@@ -263,7 +264,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 15: "+new String(info);
-		long mqs=Tools.parseLong(info, a, b);
+		long mqs=Parse.parseLong(info, a, b);
 		b++;
 		a=b;
 
@@ -271,7 +272,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 16: "+new String(info);
-		int mqm=Tools.parseInt(info, a, b);
+		int mqm=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 		
@@ -280,7 +281,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 17: "+new String(info);
-		long bqs=Tools.parseLong(info, a, b);
+		long bqs=Parse.parseLong(info, a, b);
 		b++;
 		a=b;
 
@@ -288,16 +289,16 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 18: "+new String(info);
-		int bqm=Tools.parseInt(info, a, b);
+		int bqm=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 
-		//EDS=18;EDM=9;IDS=1984;IDM=992;
+		//EDS=18;EDM=9;IDS=1984;IDM=992;NVC=0;FLG=0;
 		while(b<info.length && info[b]!='='){b++;}
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 19: "+new String(info);
-		long eds=Tools.parseLong(info, a, b);
+		long eds=Parse.parseLong(info, a, b);
 		b++;
 		a=b;
 
@@ -305,7 +306,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 20: "+new String(info);
-		int edm=Tools.parseInt(info, a, b);
+		int edm=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
 		
@@ -314,7 +315,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 21: "+new String(info);
-		long ids=Tools.parseLong(info, a, b);
+		long ids=Parse.parseLong(info, a, b);
 		b++;
 		a=b;
 
@@ -322,16 +323,35 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		a=b+1;
 		while(b<info.length && info[b]!=';'){b++;}
 		assert(b>a) : "Missing field 22: "+new String(info);
-		int idm=Tools.parseInt(info, a, b);
+		int idm=Parse.parseInt(info, a, b);
 		b++;
 		a=b;
+		
+		assert(Tools.startsWith(info, "NVC", a));
+		while(b<info.length && info[b]!='='){b++;}
+		a=b+1;
+		while(b<info.length && info[b]!=';'){b++;}
+		assert(b>a) : "Missing field 23: "+new String(info);
+		int nvc=Parse.parseInt(info, a, b);
+		b++;
+		a=b;
+		
+		assert(Tools.startsWith(info, "FLG", a));
+		while(b<info.length && info[b]!='='){b++;}
+		a=b+1;
+		while(b<info.length && info[b]!=';'){b++;}
+		assert(b>a) : "Missing field 24: "+new String(info);
+		int flg=Parse.parseInt(info, a, b);
+		b++;
+		a=b;
+		
 //		//CED=13;HMP=1;SB=0.9980;DP=24;DP4=22,0,2,0
 //		assert(Tools.startsWith(info, "CED", a));
 //		while(b<info.length && info[b]!='='){b++;}
 //		a=b+1;
 //		while(b<info.length && info[b]!=';'){b++;}
 //		assert(b>a) : "Missing field 23: "+new String(info);
-////		int ced=Tools.parseInt(info, a, b);
+////		int ced=Parse.parseInt(info, a, b);
 //		b++;
 //		a=b;
 //		
@@ -341,7 +361,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 //		a=b+1;
 //		while(b<info.length && info[b]!=';'){b++;}
 //		assert(b>a) : "Missing field 24: "+new String(info);
-////		int hmp=Tools.parseInt(info, a, b);
+////		int hmp=Parse.parseInt(info, a, b);
 //		b++;
 //		a=b;
 //		
@@ -349,7 +369,7 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 //		a=b+1;
 //		while(b<info.length && info[b]!=';'){b++;}
 //		assert(b>a) : "Missing field 25: "+new String(info);
-////		double sb=Tools.parseDouble(info, a, b);
+////		double sb=Parse.parseDouble(info, a, b);
 //		b++;
 //		a=b;
 //
@@ -384,6 +404,8 @@ public class VCFLine implements Comparable<VCFLine>, Cloneable {
 		v.endDistMax=edm;
 		v.idSum=ids;
 		v.idMax=idm;
+		v.nearbyVarCount=nvc;
+		v.setFlagged(flg>0);
 		v.revisedAlleleFraction=raf;
 		v.setCoverage(cov, mcov);
 //		v.homopolymerCount=hmp; //derived
