@@ -3,7 +3,7 @@
 usage(){
 echo "
 Written by Brian Bushnell
-Last modified November 7, 2019
+Last modified October 5, 2022
 
 Description:  Sorts reads by name or other keys such as length,
 quality, mapping position, flowcell coordinates, or taxonomy.
@@ -12,27 +12,41 @@ Writes temp files if memory is exceeded.
 Usage:   sortbyname.sh in=<file> out=<file>
 
 Input may be fasta, fastq, or sam, compressed or uncompressed.
+Temp files will use the same format as the output.  Pairs are
+kept together if reads are paired, and in2/out2 may be used for that.
+
+Example 1 - sort by name:
+sortbyname.sh in=raw.fq out=sorted.fq
+Example 2 - sort by sequence:
+sortbyname.sh in=raw.fq out=sorted.fq sequence
+Example 3 - sort by mapping position:
+sortbyname.sh in=mapped.sam out=sorted.sam position
 
 Parameters:
 
 in=<file>       Input file.
 out=<file>      Output file.
-delete=t        Delete temporary files.
-allowtemp=t     Allow writing temporary files.
 name=t          Sort reads by name.
 length=f        Sort reads by length.
 quality=f       Sort reads by quality.
 position=f      Sort reads by position (for mapped reads).
 taxa=f          Sort reads by taxonomy (for NCBI naming convention).
 sequence=f      Sort reads by sequence, alphabetically.
+clump=f         Sort reads by shared kmers, like Clumpify.
 flowcell=f      Sort reads by flowcell coordinates.
 shuffle=f       Shuffle reads randomly (untested).
 list=<file>     Sort reads according to this list of names.
 ascending=t     Sort ascending.
-memmult=.35     Write a temp file when used memory drops below this
-                fraction of total memory.
 
-Taxonomy-sorting parameters:
+Memory parameters (you might reduce these if you experience a crash)
+memmult=0.30    Write a temp file when used memory exceeds this fraction
+                of available memory.
+memlimit=0.65   Wait for temp files to finish writing until used memory
+                drops below this fraction of available memory.
+delete=t        Delete temporary files.
+allowtemp=t     Allow writing temporary files.
+
+Taxonomy-sorting parameters (for taxa mode only):
 tree=           Specify a taxtree file.  On Genepool, use 'auto'.
 gi=             Specify a gitable file.  On Genepool, use 'auto'.
 accession=      Specify one or more comma-delimited NCBI accession to
